import reflex as rx

from src.export import export
from src.docs.library.javascript_integrations.fuse.fuse import (
    fuse_cdn_script,
    load_json_file_and_initialize,
    custom_search_script,
)
from src.docs.library.javascript_integrations.minisearch.minisearch import (
    minisearch_cdn_script,
    custom_minisearch_search_script,
    load_json_file_and_initialize_minisearch,
)
from src.docs.library.javascript_integrations.quill.quill import (
    quill_stylesheet,
    quill_custom_font,
    quill_init,
    quill_lib,
)

# --- Reflex app init ---
app = rx.App(
    stylesheets=["css/wrapper.css"],
    head_components=[
        fuse_cdn_script(),
        custom_search_script(),
        minisearch_cdn_script(),
        custom_minisearch_search_script(),
        load_json_file_and_initialize(),
        load_json_file_and_initialize_minisearch(),
        quill_lib(),
        quill_stylesheet(),
        quill_custom_font(),
        quill_init(),
    ],
)

# --- Main export entry ---
export(app)



import reflex as rx

import src.routes as routes

from src.templates.drawer import drawer
from src.templates.search import site_search
from src.comps.ui.titles import site_title
from src.docs.library.base_ui.components.base.button import button
from src.comps.ui.buttons import site_github, site_theme


def main_navbar_nav_link(nav: str, url: str):
    return rx.el.a(
        button(nav, variant="ghost", size="sm", class_name="!text-sm cursor-pointer"),
        to=f"/{url}",
        class_name="",
    )


def main_navbar():
    return rx.el.div(
        rx.el.div(
            rx.el.div(
                rx.el.div(drawer(), class_name="flex lg:hidden"),
                rx.el.a(button(site_title(), variant="ghost"), to="/"),
                rx.el.div(
                    main_navbar_nav_link("Docs", routes.GET_STARTED_URLS[0]["url"]),
                    main_navbar_nav_link(
                        "Components", routes.BASE_UI_COMPONENTS[0]["url"]
                    ),
                    main_navbar_nav_link("Charts", routes.CHARTS_URLS[0]["url"]),
                    main_navbar_nav_link(
                        "Wrapped React", routes.WRAPPED_COMPONENTS_URLS[0]["url"]
                    ),
                    main_navbar_nav_link(
                        "Integrations", routes.JS_INTEGRATIONS_URLS[0]["url"]
                    ),
                    class_name="hidden lg:flex flex-row items-center text-sm no-underline gap-x-2",
                ),
                class_name="flex flex-row items-baseline gap-x-2 lg:gap-x-4",
            ),
            rx.el.div(
                site_search(),
                rx.el.p(
                    "|", class_name="text-muted-foreground/50 font-thin hidden lg:flex"
                ),
                site_github(),
                rx.el.p("|", class_name="text-muted-foreground/50 font-thin"),
                site_theme(),
                class_name="flex flex-row items-center gap-x-2",
            ),
            class_name="xl:max-w-[80rem] 2xl:max-w-[85rem] w-full mx-auto flex flex-row items-center justify-between",
        ),
        class_name="bg-background w-full h-12 sticky top-0 left-0 px-0 py-7 items-center justify-between flex flex-row z-[99999]",
    )



# --- Simple frontmatter parser. ---
def parse_frontmatter(content: str) -> tuple[dict, str]:
    """A simple frontmatter parser."""
    metadata = {}
    if not content.startswith("---"):
        return metadata, content

    parts = content.split("---", 2)
    if len(parts) < 3:
        return metadata, content

    frontmatter = parts[1]
    rest_of_content = parts[2]

    for line in frontmatter.strip().split("\n"):
        if ":" in line:
            key, value = line.split(":", 1)
            key = key.strip()
            value = value.strip()

            if (value.startswith('"') and value.endswith('"')) or (
                value.startswith("'") and value.endswith("'")
            ):
                value = value[1:-1]

            if key == "order" and value.isdigit():
                value = int(value)

            metadata[key] = value

    return metadata, rest_of_content.lstrip()



import typer
import pathlib
import shutil
import ast
import subprocess
import re

app = typer.Typer()
add_app = typer.Typer()
app.add_typer(add_app, name="add")

# --- Constants ---
REPO_URL = "https://github.com/sapphireUI/SapphireUI.git"
CACHE_DIR = pathlib.Path.home() / ".sapphireui" / "repo"

# Source directories from the cloned repo
BASE_UI_DIR = CACHE_DIR / "src" / "docs" / "library" / "base_ui"
BASE_UI_COMPONENTS_DIR = BASE_UI_DIR / "components"
BASE_UI_BASE_COMPONENTS_DIR = BASE_UI_COMPONENTS_DIR / "base"
BASE_UI_ICONS_DIR = BASE_UI_DIR / "icons"
BASE_UI_UTILS_DIR = BASE_UI_DIR / "utils"

WRAPPED_COMPONENTS_DIR = CACHE_DIR / "src" / "docs" / "library" / "wrapped_components"
THEMES_CSS_FILE = CACHE_DIR / "assets" / "css" / "wrapper.css"


def _run_git_command(command: list[str], cwd: pathlib.Path | None = None):
    """Runs a git command and handles errors."""
    try:
        subprocess.run(command, check=True, capture_output=True, text=True)
    except FileNotFoundError:
        typer.secho(
            "Error: git is not installed. Please install git to use this feature.",
            fg=typer.colors.RED,
        )
        raise typer.Exit(1)
    except subprocess.CalledProcessError as e:
        typer.secho(f"Git command failed: {e.stderr}", fg=typer.colors.RED)
        raise typer.Exit(1)


def _update_repo():
    """Clones or pulls the SapphireUI repository."""
    typer.secho("Updating component library...", fg=typer.colors.YELLOW)
    if not CACHE_DIR.exists():
        typer.echo(f"Cloning repository into {CACHE_DIR}...")
        CACHE_DIR.parent.mkdir(parents=True, exist_ok=True)
        _run_git_command(["git", "clone", REPO_URL, str(CACHE_DIR)])
    else:
        typer.echo(f"Pulling latest changes in {CACHE_DIR}...")
        _run_git_command(["git", "-C", str(CACHE_DIR), "pull"])
    typer.secho("Component library is up to date.", fg=typer.colors.GREEN)


def _find_base_ui_component_imports(file_path: pathlib.Path) -> list[str]:
    """Parses a Python file and returns a list of local component dependencies."""
    if not file_path.exists():
        return []
    content = file_path.read_text()
    tree = ast.parse(content)
    dependencies = []
    for node in ast.walk(tree):
        if isinstance(node, ast.ImportFrom) and node.level == 1:
            # Assuming level 1 imports are peer dependencies in the same 'base' directory
            if node.module:
                dependencies.append(node.module)
    return list(set(dependencies))


def _copy_base_ui_scaffolding(app_root_dir: pathlib.Path):
    """Copies the base UI scaffolding (utils, icons, and base component files)."""
    dest_dir = app_root_dir / "components" / "ui"
    dest_dir.mkdir(parents=True, exist_ok=True)
    (dest_dir.parent / "__init__.py").touch()
    (dest_dir / "__init__.py").touch()

    # Copy icons and utils directories
    icons_dest = dest_dir / "icons"
    if not icons_dest.exists():
        shutil.copytree(BASE_UI_ICONS_DIR, icons_dest)
        typer.secho(
            f"  - Added icons to {icons_dest.relative_to(pathlib.Path.cwd())}",
            fg=typer.colors.BLUE,
        )

    utils_dest = dest_dir / "utils"
    if not utils_dest.exists():
        shutil.copytree(BASE_UI_UTILS_DIR, utils_dest)
        typer.secho(
            f"  - Added utils to {utils_dest.relative_to(pathlib.Path.cwd())}",
            fg=typer.colors.BLUE,
        )

    # Copy base_ui.py and component.py
    for base_file in ["base_ui.py", "component.py"]:
        source = BASE_UI_COMPONENTS_DIR / base_file
        dest = dest_dir / base_file
        if not dest.exists():
            shutil.copy(source, dest)
            typer.secho(
                f"  - Added base file '{base_file}' to {dest.relative_to(pathlib.Path.cwd())}",
                fg=typer.colors.BLUE,
            )

    # Ensure base component directory exists
    (dest_dir / "base").mkdir(exist_ok=True)
    (dest_dir / "base" / "__init__.py").touch()


def _add_base_ui_component(
    component_name: str, added_items: set, app_root_dir: pathlib.Path
):
    """Adds a single base_ui component and its dependencies."""
    if component_name in added_items:
        return

    source_file = BASE_UI_BASE_COMPONENTS_DIR / f"{component_name}.py"
    if not source_file.exists():
        typer.secho(
            f"Component '{component_name}' not found in base_ui components.",
            fg=typer.colors.RED,
        )
        # Check for older components for backward compatibility
        old_source_file = (
            CACHE_DIR
            / "src"
            / "docs"
            / "library"
            / "components"
            / component_name
            / f"{component_name}.py"
        )
        if old_source_file.exists():
            typer.secho(
                f"Note: '{component_name}' seems to be an older component. Please check its dependencies manually.",
                fg=typer.colors.YELLOW,
            )
            # Fallback to old logic if needed, or just inform user. For now, just informing.
        return

    added_items.add(component_name)

    # Copy scaffolding first
    if "base_ui_scaffold" not in added_items:
        _copy_base_ui_scaffolding(app_root_dir)
        added_items.add("base_ui_scaffold")

    dest_file = app_root_dir / "components" / "ui" / "base" / f"{component_name}.py"
    shutil.copy(source_file, dest_file)
    typer.secho(
        f"  - Added component '{component_name}' to {dest_file.relative_to(pathlib.Path.cwd())}",
        fg=typer.colors.CYAN,
    )

    dependencies = _find_base_ui_component_imports(source_file)
    for dep_name in dependencies:
        _add_base_ui_component(dep_name, added_items, app_root_dir)


@add_app.command("component")
def add_component(component: str):
    """
    Add a component and its dependencies to your Reflex project.
    """
    _check_reflex_project()
    app_name = _get_app_name()
    app_root_dir = pathlib.Path.cwd() / app_name

    _update_repo()
    typer.secho(f"Adding component: '{component}'...", fg=typer.colors.GREEN)
    added_items = set()
    _add_base_ui_component(component, added_items, app_root_dir)
    typer.secho("Done.", fg=typer.colors.GREEN)


def _find_util_imports(file_path: pathlib.Path) -> list[str]:
    """Parses a Python file and returns a list of util dependencies."""
    if not file_path.exists():
        return []
    content = file_path.read_text()
    tree = ast.parse(content)
    dependencies = []
    for node in ast.walk(tree):
        if isinstance(node, ast.ImportFrom):
            if node.module and node.module.startswith("src.utils"):
                util_name = node.module.split(".")[2]
                dependencies.append(util_name)
    return list(set(dependencies))


def _add_wrapped_react(
    component_name: str, added_items: set, app_root_dir: pathlib.Path
):
    """Adds a single wrapped react component and its utility dependencies."""
    if component_name in added_items:
        return
    added_items.add(component_name)

    source_file = WRAPPED_COMPONENTS_DIR / f"{component_name}.py"
    if not source_file.is_file():
        source_file = WRAPPED_COMPONENTS_DIR / component_name / f"{component_name}.py"

    if not source_file.exists():
        typer.secho(
            f"Wrapped React component '{component_name}' not found in repository.",
            fg=typer.colors.RED,
        )
        return

    dest_dir = app_root_dir / "components" / "wrapped_react"
    dest_dir.mkdir(parents=True, exist_ok=True)
    (dest_dir / "__init__.py").touch()
    (dest_dir.parent / "__init__.py").touch()

    dest_file = dest_dir / f"{component_name}.py"
    shutil.copy(source_file, dest_file)
    typer.secho(
        f"  - Added wrapped react component '{component_name}' to {dest_file.relative_to(pathlib.Path.cwd())}",
        fg=typer.colors.CYAN,
    )

    # Wrapped components might have util dependencies from the old structure
    dependencies = _find_util_imports(dest_file)
    if dependencies:
        # This part needs to be thought out. For now, let's assume wrapped components are self-contained
        # or their utils are handled differently. The user request is about base_ui components.
        typer.secho(
            f"  - Note: Wrapped component might have legacy util dependencies: {dependencies}. Please verify.",
            fg=typer.colors.YELLOW,
        )


@add_app.command("wrapped-react")
def add_wrapped_react(component: str):
    """
    Add a wrapped React component and its dependencies to your Reflex project.
    """
    _check_reflex_project()
    app_name = _get_app_name()
    app_root_dir = pathlib.Path.cwd() / app_name

    _update_repo()
    typer.secho(
        f"Adding wrapped React component: '{component}'...", fg=typer.colors.GREEN
    )
    added_items = set()
    _add_wrapped_react(component, added_items, app_root_dir)
    typer.secho("Done.", fg=typer.colors.GREEN)


def _extract_theme_css(theme_name: str) -> str:
    """Extracts the CSS for a given theme and its dark variant from wrapper.css."""
    if not THEMES_CSS_FILE.exists():
        typer.secho(
            f"Error: Theme CSS file not found at {THEMES_CSS_FILE}.",
            fg=typer.colors.RED,
        )
        raise typer.Exit(1)

    content = THEMES_CSS_FILE.read_text()
    extracted_css = []

    # Regex to find the light theme block
    light_theme_pattern = re.compile(
        rf"(\.(?:theme-{re.escape(theme_name)}))\s*{{([^}}]*)}}", re.DOTALL
    )
    # Regex to find the dark theme block
    dark_theme_pattern = re.compile(
        rf"(\.(?:theme-{re.escape(theme_name)}-dark))\s*{{([^}}]*)}}", re.DOTALL
    )

    light_match = light_theme_pattern.search(content)
    if light_match:
        extracted_css.append(f"{light_match.group(1)} {{{light_match.group(2)}}}")
    else:
        typer.secho(
            f"Warning: Light theme '.theme-{theme_name}' not found in wrapper.css.",
            fg=typer.colors.YELLOW,
        )

    dark_match = dark_theme_pattern.search(content)
    if dark_match:
        extracted_css.append(f"{dark_match.group(1)} {{{dark_match.group(2)}}}")
    else:
        typer.secho(
            f"Warning: Dark theme '.theme-{theme_name}-dark' not found in wrapper.css.",
            fg=typer.colors.YELLOW,
        )

    if not extracted_css:
        typer.secho(
            f"Error: No CSS found for theme '{theme_name}' or its dark variant.",
            fg=typer.colors.RED,
        )
        raise typer.Exit(1)

    return "\n\n".join(extracted_css)


@add_app.command("theme")
def add_theme(theme_name: str):
    """
    Add a theme (light and dark variants) to your Reflex project.
    """
    _check_reflex_project()
    project_root_dir = pathlib.Path.cwd()

    _update_repo()
    typer.secho(f"Adding theme: '{theme_name}'...", fg=typer.colors.GREEN)

    theme_css_content = _extract_theme_css(theme_name)

    dest_css_dir = project_root_dir / "assets" / "css"
    dest_css_dir.mkdir(parents=True, exist_ok=True)

    dest_file = dest_css_dir / f"{theme_name}.css"
    dest_file.write_text(theme_css_content)
    typer.secho(
        f"  - Added theme '{theme_name}' to {dest_file.relative_to(pathlib.Path.cwd())}",
        fg=typer.colors.CYAN,
    )
    typer.secho("Done.", fg=typer.colors.GREEN)


def _get_app_name() -> str:
    """Parses rxconfig.py to find the app_name."""
    rxconfig_path = pathlib.Path.cwd() / "rxconfig.py"
    content = rxconfig_path.read_text()
    tree = ast.parse(content)

    app_name = None
    for node in ast.walk(tree):
        if isinstance(node, ast.Assign):
            if isinstance(node.targets[0], ast.Name) and node.targets[0].id == "config":
                if isinstance(node.value, ast.Call):
                    if isinstance(node.value.func, (ast.Name, ast.Attribute)):
                        for keyword in node.value.keywords:
                            if keyword.arg == "app_name":
                                if isinstance(keyword.value, ast.Constant):
                                    app_name = keyword.value.value
                                    break
            if app_name:
                break

    if not app_name:
        typer.secho(
            "Error: Could not find 'app_name' in rxconfig.py.", fg=typer.colors.RED
        )
        raise typer.Exit(1)
    return str(app_name)


def _check_reflex_project():
    """Check if the command is run from the root of a Reflex project."""
    if not (pathlib.Path.cwd() / "rxconfig.py").exists():
        typer.secho(
            "Error: This command must be run from the root of a Reflex project.",
            fg=typer.colors.RED,
        )
        typer.secho("('rxconfig.py' not found)", fg=typer.colors.RED)
        raise typer.Exit(1)


@app.command("list")
def list_all():
    """
    List all available items (components, wrapped React components, themes) in the Buridan UI library.
    """
    _update_repo()
    typer.echo("Listing available items from repository...")

    # List Standard Components from base_ui
    if BASE_UI_BASE_COMPONENTS_DIR.exists():
        components = [
            p.stem
            for p in BASE_UI_BASE_COMPONENTS_DIR.iterdir()
            if p.suffix == ".py" and not p.name.startswith("__")
        ]
        typer.echo("\n--- Base UI Components ---")
        for component in sorted(components):
            typer.echo(f"- {component}")

    # List Wrapped React Components
    if WRAPPED_COMPONENTS_DIR.exists():
        wrapped_components = []
        for p in WRAPPED_COMPONENTS_DIR.iterdir():
            if p.name.startswith("__"):
                continue
            if p.is_dir():
                # It's a directory, so it's a component
                wrapped_components.append(p.name)
            elif p.suffix == ".py":
                # It's a file, so it's a component
                wrapped_components.append(p.stem)

        typer.echo("\n--- Wrapped React Components ---")
        for component in sorted(list(set(wrapped_components))):
            typer.echo(f"- {component}")

    # List Themes
    themes = set()
    if THEMES_CSS_FILE.exists():
        content = THEMES_CSS_FILE.read_text()
        theme_pattern = re.compile(r"\.theme-([a-zA-Z0-9-]+)(?:-dark)?\s*\{")
        for match in theme_pattern.finditer(content):
            themes.add(match.group(1))
    typer.echo("\n--- Themes ---")
    for theme in sorted(list(themes)):
        typer.echo(f"- {theme}")


if __name__ == "__main__":
    app()



"""Custom tabs component."""

from typing import Literal

from reflex.components.component import Component, ComponentNamespace
from reflex.event import EventHandler, passthrough_event_spec
from reflex.utils.imports import ImportVar
from reflex.vars.base import Var

from ..base_ui import PACKAGE_NAME, BaseUIComponent

LiteralOrientation = Literal["horizontal", "vertical"]


class ClassNames:
    """Class names for tabs components."""

    ROOT = "flex flex-col gap-2"
    LIST = "relative bg-muted text-muted-foreground inline-flex h-9 w-fit items-center justify-center rounded-lg p-[3px]"
    TAB = (
        "relative z-[2] "
        "focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:outline-ring "
        "text-foreground dark:text-muted-foreground "
        "data-[selected]:text-foreground dark:data-[selected]:text-foreground "
        "inline-flex h-[calc(100%-1px)] flex-1 items-center justify-center gap-1.5 "
        "rounded-md border border-transparent px-2 py-1 text-sm font-medium whitespace-nowrap "
        "transition-all duration-200 ease-in-out "
        "focus-visible:ring-[3px] focus-visible:outline-1 "
        "disabled:pointer-events-none disabled:opacity-50 "
        "[&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4"
    )
    INDICATOR = (
        "absolute z-[1] rounded-md bg-background shadow-sm dark:border dark:border-input dark:bg-input/30 "
        "transition-all duration-200 ease-in-out "
        "[left:var(--active-tab-left)] [top:var(--active-tab-top)] "
        "[width:var(--active-tab-width)] [height:var(--active-tab-height)]"
    )
    PANEL = "flex flex-col gap-2"


class TabsBaseComponent(BaseUIComponent):
    """Base component for tabs components."""

    library = f"{PACKAGE_NAME}/tabs"

    @property
    def import_var(self):
        """Return the import variable for the tabs component."""
        return ImportVar(tag="Tabs", package_path="", install=False)


class TabsRoot(TabsBaseComponent):
    """Groups the tabs and the corresponding panels. Renders a <div> element."""

    tag = "Tabs.Root"

    # The default value. Use when the component is not controlled. When the value is null, no Tab will be selected. Defaults to 0.
    default_value: Var[str | int]

    # The value of the currently selected Tab. Use when the component is controlled. When the value is null, no Tab will be selected.
    value: Var[str | int]

    # Callback invoked when new value is being set.
    on_value_change: EventHandler[passthrough_event_spec(str | dict)]

    # The component orientation (layout flow direction). Defaults to "horizontal".
    orientation: Var[LiteralOrientation]

    # The render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the tabs root component."""
        props["data-slot"] = "tabs"
        cls.set_class_name(ClassNames.ROOT, props)
        return super().create(*children, **props)


class TabsList(TabsBaseComponent):
    """Groups the individual tab buttons. Renders a <div> element."""

    tag = "Tabs.List"

    # Whether to automatically change the active tab on arrow key focus. Otherwise, tabs will be activated using Enter or Spacebar key press. Defaults to True.
    activate_on_focus: Var[bool]

    # Whether to loop keyboard focus back to the first item when the end of the list is reached while using the arrow keys. Defaults to True.
    loop: Var[bool]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the tabs list component."""
        props["data-slot"] = "tabs-list"
        cls.set_class_name(ClassNames.LIST, props)
        return super().create(*children, **props)


class TabsTab(TabsBaseComponent):
    """An individual interactive tab button that toggles the corresponding panel. Renders a <button> element."""

    tag = "Tabs.Tab"

    # The value of the Tab. When not specified, the value is the child position index.
    value: Var[str | int]

    # Whether the component renders a native <button> element when replacing it via the render prop. Set to false if the rendered element is not a button (e.g. <div>). Defaults to True.
    native_button: Var[bool]

    # Whether the Tab is disabled. Defaults to false.
    disabled: Var[bool]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the tabs tab component."""
        props["data-slot"] = "tabs-tab"
        cls.set_class_name(ClassNames.TAB, props)
        return super().create(*children, **props)


class TabsIndicator(TabsBaseComponent):
    """A visual indicator that can be styled to match the position of the currently active tab. Renders a <span> element."""

    tag = "Tabs.Indicator"

    # Whether to render itself before React hydrates. This minimizes the time that the indicator isn't visible after server-side rendering. Defaults to False.
    render_before_hydration: Var[bool]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the tabs indicator component."""
        props["data-slot"] = "tabs-indicator"
        cls.set_class_name(ClassNames.INDICATOR, props)
        return super().create(*children, **props)


class TabsPanel(TabsBaseComponent):
    """A panel displayed when the corresponding tab is active. Renders a <div> element."""

    tag = "Tabs.Panel"

    # The value of the TabPanel. It will be shown when the Tab with the corresponding value is selected. If not provided, it will fall back to the index of the panel. It is recommended to explicitly provide it, as it's required for the tab panel to be rendered on the server.
    value: Var[str | int]

    # Whether to keep the HTML element in the DOM while the panel is hidden. Defaults to False.
    keep_mounted: Var[bool]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the tabs panel component."""
        props["data-slot"] = "tabs-panel"
        cls.set_class_name(ClassNames.PANEL, props)
        return super().create(*children, **props)


class Tabs(ComponentNamespace):
    """Namespace for Tabs components."""

    root = __call__ = staticmethod(TabsRoot.create)
    list = staticmethod(TabsList.create)
    tab = staticmethod(TabsTab.create)
    panel = staticmethod(TabsPanel.create)
    indicator = staticmethod(TabsIndicator.create)
    class_names = ClassNames


tabs = Tabs()



import reflex as rx
from ...base_ui.components.base.toggle_group import toggle_group
from ...base_ui.components.base.toggle import toggle


def toggle_group_example():
    """A basic toggle group example."""
    return toggle_group(
        toggle(
            rx.icon("bold"),
            value="bold",
            class_name="flex size-8 items-center justify-center rounded-sm active:bg-secondary text-muted-foreground active:text-foreground",
        ),
        toggle(
            rx.icon("italic"),
            value="italic",
            class_name="flex size-8 items-center justify-center rounded-sm active:bg-secondary text-muted-foreground active:text-foreground",
        ),
        toggle(
            rx.icon("underline"),
            value="underline",
            class_name="flex size-8 items-center justify-center rounded-sm active:bg-secondary text-muted-foreground active:text-foreground",
        ),
        default_value=["bold"],
        class_name="flex gap-px rounded-md border border-input bg-background p-0.5",
    )


def toggle_group_multiple():
    """A toggle group example allowing multiple selections."""
    return toggle_group(
        toggle(
            rx.icon("align-left"),
            value="left",
            class_name="flex size-8 items-center justify-center rounded-sm active:bg-secondary text-muted-foreground active:text-foreground",
        ),
        toggle(
            rx.icon("align-center"),
            value="center",
            class_name="flex size-8 items-center justify-center rounded-sm active:bg-secondary text-muted-foreground active:text-foreground",
        ),
        toggle(
            rx.icon("align-right"),
            value="right",
            class_name="flex size-8 items-center justify-center rounded-sm active:bg-secondary text-muted-foreground active:text-foreground",
        ),
        default_value=["left", "right"],
        multiple=True,
        class_name="flex gap-px rounded-md border border-input bg-background p-0.5",
    )


def toggle_group_disabled():
    """A disabled toggle group example."""
    return toggle_group(
        toggle(rx.icon("bold"), value="bold"),
        toggle(rx.icon("italic"), value="italic"),
        toggle(rx.icon("underline"), value="underline"),
        disabled=True,
    )



"""Custom dialog component."""

from typing import Literal

from reflex.components.component import Component, ComponentNamespace
from reflex.components.el import Div
from reflex.event import EventHandler, passthrough_event_spec
from reflex.utils.imports import ImportVar
from reflex.vars.base import Var

from .button import button
from ..base_ui import PACKAGE_NAME, BaseUIComponent
from ...icons.hugeicon import hi


class ClassNames:
    """Class names for dialog components."""

    BACKDROP = "data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 fixed inset-0 z-50 bg-black/50"
    POPUP = "bg-background data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 fixed top-[50%] left-[50%] z-50 grid w-full max-w-[calc(100%-2rem)] translate-x-[-50%] translate-y-[-50%] gap-4 rounded-lg border border-input p-6 shadow-lg duration-200 sm:max-w-lg"
    TITLE = "text-lg leading-none font-semibold"
    DESCRIPTION = "text-muted-foreground text-sm"
    HEADER = "flex flex-col"
    CONTENT = "flex flex-col"
    TRIGGER = ""
    CLOSE = ""


class DialogBaseComponent(BaseUIComponent):
    """Base component for dialog components."""

    library = f"{PACKAGE_NAME}/dialog"

    @property
    def import_var(self):
        """Return the import variable for the dialog component."""
        return ImportVar(tag="Dialog", package_path="", install=False)


class DialogRoot(DialogBaseComponent):
    """Groups all parts of the dialog. Doesn't render its own HTML element."""

    tag = "Dialog.Root"

    # Whether the dialog is initially open. To render a controlled dialog, use the open prop instead.
    default_open: Var[bool]

    # Whether the dialog is currently open.
    open: Var[bool]

    # Event handler called when the dialog is opened or closed
    on_open_change: EventHandler[passthrough_event_spec(bool, dict)]

    # Determines whether the dialog should close on outside clicks. Defaults to True.
    dismissible: Var[bool]

    # Determines if the dialog enters a modal state when open.
    # - True: user interaction is limited to just the dialog: focus is trapped, document page scroll is locked, and pointer interactions on outside elements are disabled.
    # - False: user interaction with the rest of the document is allowed.
    # - 'trap-focus': focus is trapped inside the dialog, but document page scroll is not locked and pointer interactions outside of it remain enabled.
    modal: Var[bool | Literal["trap-focus"]]

    # Event handler called after any animations complete when the dialog is opened or closed.
    on_open_change_complete: EventHandler[passthrough_event_spec(bool)]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the dialog root component."""
        props["data-slot"] = "dialog"
        return super().create(*children, **props)


class DialogTrigger(DialogBaseComponent):
    """A button that opens the dialog. Renders a <button> element."""

    tag = "Dialog.Trigger"

    # Whether the component renders a native <button> element when replacing it via the render prop. Set to false if the rendered element is not a button (e.g. <div>). Defaults to True.
    native_button: Var[bool]

    # The render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the dialog trigger component."""
        props["data-slot"] = "dialog-trigger"
        cls.set_class_name(ClassNames.TRIGGER, props)
        return super().create(*children, **props)


class DialogPortal(DialogBaseComponent):
    """A portal element that moves the popup to a different part of the DOM. By default, the portal element is appended to <body>."""

    tag = "Dialog.Portal"

    # A parent element to render the portal element into.
    container: Var[str]

    # Whether to keep the portal mounted in the DOM while the popup is hidden. Defaults to False.
    keep_mounted: Var[bool]


class DialogBackdrop(DialogBaseComponent):
    """An overlay displayed beneath the popup. Renders a <div> element."""

    tag = "Dialog.Backdrop"

    # Whether the backdrop is forced to render even when nested. Defaults to False.
    force_render: Var[bool]

    # The render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the dialog backdrop component."""
        props["data-slot"] = "dialog-backdrop"
        cls.set_class_name(ClassNames.BACKDROP, props)
        return super().create(*children, **props)


class DialogPopup(DialogBaseComponent):
    """A container for the dialog contents. Renders a <div> element."""

    tag = "Dialog.Popup"

    # Determines the element to focus when the dialog is opened. By default, the first focusable element is focused.
    initial_focus: Var[str]

    # Determines the element to focus when the dialog is closed. By default, focus returns to the trigger.
    final_focus: Var[str]

    # The render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the dialog popup component."""
        props["data-slot"] = "dialog-popup"
        cls.set_class_name(ClassNames.POPUP, props)
        return super().create(*children, **props)


class DialogTitle(DialogBaseComponent):
    """A heading that labels the dialog. Renders an <h2> element."""

    tag = "Dialog.Title"

    # The render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the dialog title component."""
        props["data-slot"] = "dialog-title"
        cls.set_class_name(ClassNames.TITLE, props)
        return super().create(*children, **props)


class DialogDescription(DialogBaseComponent):
    """A paragraph with additional information about the dialog. Renders a <p> element.."""

    tag = "Dialog.Description"

    # The render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the dialog description component."""
        props["data-slot"] = "dialog-description"
        cls.set_class_name(ClassNames.DESCRIPTION, props)
        return super().create(*children, **props)


class DialogClose(DialogBaseComponent):
    """A paragraph with additional information about the dialog. Renders a <p> element."""

    tag = "Dialog.Close"

    # Whether the component renders a native <button> element when replacing it via the render prop. Set to false if the rendered element is not a button (e.g. <div>). Defaults to True.
    native_button: Var[bool]

    # The render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the dialog close component."""
        props["data-slot"] = "dialog-close"
        cls.set_class_name(ClassNames.CLOSE, props)
        return super().create(*children, **props)


class HighLevelDialog(DialogRoot):
    """High level dialog component."""

    # Dialog props
    trigger: Var[Component | None]
    content: Var[str | Component | None]
    title: Var[str | Component | None]
    description: Var[str | Component | None]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the dialog component."""
        trigger = props.pop("trigger", None)
        content = props.pop("content", None)
        title = props.pop("title", None)
        description = props.pop("description", None)
        class_name = props.pop("class_name", "")

        return DialogRoot.create(
            DialogTrigger.create(render_=trigger) if trigger is not None else None,
            DialogPortal.create(
                DialogBackdrop.create(),
                DialogPopup.create(
                    Div.create(
                        Div.create(
                            DialogTitle.create(title) if title is not None else None,
                            DialogClose.create(
                                render_=button(
                                    hi("Cancel01Icon"),
                                    variant="ghost",
                                    size="icon-sm",
                                    class_name="text-secondary-11",
                                ),
                            ),
                            class_name="flex flex-row justify-between items-baseline gap-1",
                        ),
                        (
                            DialogDescription.create(description)
                            if description is not None
                            else None
                        ),
                        data_slot="dialog-header",
                        class_name=ClassNames.HEADER,
                    ),
                    Div.create(
                        content,
                        data_slot="dialog-content",
                        class_name=ClassNames.CONTENT,
                    ),
                    *children,
                    class_name=class_name,
                ),
            ),
            **props,
        )

    def _exclude_props(self) -> list[str]:
        return [
            *super()._exclude_props(),
            "trigger",
            "content",
            "title",
            "description",
        ]


class Dialog(ComponentNamespace):
    """Namespace for Dialog components."""

    root = staticmethod(DialogRoot.create)
    trigger = staticmethod(DialogTrigger.create)
    portal = staticmethod(DialogPortal.create)
    backdrop = staticmethod(DialogBackdrop.create)
    popup = staticmethod(DialogPopup.create)
    title = staticmethod(DialogTitle.create)
    description = staticmethod(DialogDescription.create)
    close = staticmethod(DialogClose.create)
    class_names = ClassNames
    __call__ = staticmethod(HighLevelDialog.create)


dialog = Dialog()



"""Custom toggle component."""

from reflex.components.component import Component
from reflex.event import EventHandler, passthrough_event_spec
from reflex.utils.imports import ImportVar
from reflex.vars.base import Var

from ..base_ui import PACKAGE_NAME, BaseUIComponent


class ClassNames:
    """Class names for toggle components."""

    ROOT = "p-1.5 inline-flex items-center justify-center gap-2 rounded-md text-sm font-medium hover:bg-muted hover:text-muted-foreground disabled:pointer-events-none disabled:opacity-50 data-[pressed]:bg-accent data-[pressed]:text-accent-foreground [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 [&_svg]:shrink-0 focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] outline-none transition-[color,box-shadow] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive whitespace-nowrap"


class ToggleBaseComponent(BaseUIComponent):
    """Base component for toggle components."""

    library = f"{PACKAGE_NAME}/toggle"

    @property
    def import_var(self):
        """Return the import variable for the toggle component."""
        return ImportVar(tag="Toggle", package_path="", install=False)


class Toggle(ToggleBaseComponent):
    """A two-state button that can be on or off. Renders a <button> element."""

    tag = "Toggle"

    # A unique string that identifies the toggle when used inside a toggle group.
    value: Var[str]

    # Whether the toggle button is currently pressed. This is the uncontrolled counterpart of pressed. Defaults to False.
    default_pressed: Var[bool]

    # Whether the toggle button is currently pressed. This is the controlled counterpart of default_pressed.
    pressed: Var[bool]

    # Callback fired when the pressed state is changed.
    on_pressed_change: EventHandler[passthrough_event_spec(bool, dict)]

    # Whether the component renders a native <button> element when replacing it via the render prop. Set to false if the rendered element is not a button (e.g. <div>). Defaults to True.
    native_button: Var[bool]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # The render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the toggle component."""
        props["data-slot"] = "toggle"
        cls.set_class_name(ClassNames.ROOT, props)
        return super().create(*children, **props)


toggle = Toggle.create



from ...base_ui.components.base.tooltip import tooltip
from ...base_ui.components.base.button import button

import reflex as rx


def tooltip_group_example():
    """A group of icon buttons with tooltips using the Tooltip API."""

    return rx.el.div(
        tooltip.provider(
            *[
                tooltip.root(
                    tooltip.trigger(
                        rx.icon(tag=icon),
                        class_name="flex size-8 items-center justify-center rounded-sm",
                    ),
                    tooltip.portal(
                        tooltip.positioner(
                            tooltip.popup(label),
                            side_offset=10,
                        )
                    ),
                )
                for icon, label in [
                    ("bold", "Bold"),
                    ("italic", "Italic"),
                    ("underline", "Underline"),
                    ("strikethrough", "Strikethrough"),
                ]
            ],
        ),
        class_name="flex !flex-row gap-px rounded-md border border-input bg-background p-0.5",
    )


def tooltip_example():
    """A basic tooltip example."""
    return tooltip(
        trigger=button("i", variant="outline"),
        content="This is a tooltip!",
    )


def tooltip_with_long_content():
    """Tooltip with longer content."""
    return tooltip(
        trigger=button("i", variant="outline"),
        content="This is a much longer tooltip content that provides more detailed information.",
    )


def tooltip_with_custom_placement():
    """Tooltip with custom placement (e.g., bottom)."""
    return tooltip(
        trigger=button("i", variant="outline"),
        content="This tooltip appears at the bottom.",
        side="bottom",
    )



import reflex as rx
from src.docs.library.charts.util import (
    get_tooltip,
    get_x_axis,
)


def barchart_v9():
    data = [
        {"month": "Jan", "desktop": 186, "mobile": 80, "tablet": 50},
        {"month": "Feb", "desktop": 305, "mobile": 200, "tablet": 120},
        {"month": "Mar", "desktop": 237, "mobile": 120, "tablet": 70},
        {"month": "Apr", "desktop": 73, "mobile": 190, "tablet": 30},
        {"month": "May", "desktop": 209, "mobile": 130, "tablet": 80},
    ]

    return rx.box(
        rx.hstack(
            rx.foreach(
                [
                    ["Desktop", "var(--chart-1)"],
                    ["Mobile", "var(--chart-2)"],
                    ["Tablet", "var(--chart-3)"],
                ],
                lambda key: rx.hstack(
                    rx.box(class_name="w-3 h-3 rounded-sm", bg=key[1]),
                    rx.text(
                        key[0],
                        class_name="text-sm font-semibold",
                        color=rx.color("slate", 11),
                    ),
                    align="center",
                    spacing="2",
                ),
            ),
            class_name="py-4 px-4 flex w-full flex justify-center gap-8",
        ),
        rx.recharts.bar_chart(
            get_tooltip(),
            rx.recharts.bar(data_key="desktop", fill="var(--chart-1)", radius=4),
            rx.recharts.bar(data_key="mobile", fill="var(--chart-2)", radius=4),
            rx.recharts.bar(data_key="tablet", fill="var(--chart-3)", radius=4),
            get_x_axis("month"),
            data=data,
            width="100%",
            height=250,
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )



import reflex as rx
from reflex.experimental import ClientStateVar

from typing import TypedDict, List

docs = ClientStateVar.create("docs", default=[], global_ref=True)
query = ClientStateVar.create("query", default="", global_ref=True)


class AuthorDict(TypedDict):
    firstName: str
    lastName: str


class ItemDict(TypedDict):
    title: str
    author: AuthorDict


class DocDict(TypedDict):
    item: ItemDict
    refIndex: int
    score: float


def fuse_cdn_script():
    return rx.script(src="https://cdn.jsdelivr.net/npm/fuse.js@7.1.0")


def custom_search_script():
    return rx.script(src="/js_integration/search/fuse.js")


def load_json_file_and_initialize():
    return rx.script(
        """
        fetch('/js_integration/search/list.json')
            .then(response => response.json())
            .then(data => {
                setTimeout(() => {
                    window.initializeFuse(data);
                    window.fuseInitialized = true;
                }, 2000);
            });
    """
    )


def search_trigger() -> rx.Component:
    """Render the search trigger button."""
    return rx.box(
        rx.icon(
            "search",
            class_name="absolute left-2 top-1/2 transform -translate-y-1/2 text-md w-4 h-4 flex-shrink-0",
        ),
        rx.el.input(
            placeholder="Search",
            read_only=True,
            class_name="bg-transparent border-none outline-none focus:outline-none pl-4 cursor-pointer hidden md:block",
        ),
        border="0.81px solid gray",
        class_name="py-[6px] px-[12px] w-full cursor-pointer flex max-h-[32px] min-h-[32px] rounded-lg border border-input relative",
    )


def no_results_found():
    return rx.box(
        rx.el.p(
            rx.fragment(
                "No results found for ",
                rx.el.strong(f"'{query.value}'"),
            ),
        ),
        class_name="w-full flex items-center justify-center text-sm py-4",
    )


def search_input():
    return rx.box(
        rx.box(
            rx.icon(
                tag="search",
                size=14,
                class_name="absolute left-2 top-1/2 transform -translate-y-1/2 !text-gray-500/40",
            ),
            rx.el.input(
                id="search_input",
                on_change=rx.call_script(
                    """
                    (() => {
                        if (!window._debouncedSearch) {
                            let timeout;
                            window._debouncedSearch = function () {
                                clearTimeout(timeout);
                                timeout = setTimeout(() => {
                                    const inputValue = document.getElementById("search_input").value;
                                    const results = window.searchFuse(inputValue);
                                    console.log("searchFuse called with query:", inputValue, results);
                                    refs._client_state_setDocs(results);
                                    refs._client_state_setQuery(inputValue);
                                }, 300);
                            };
                        }
                        window._debouncedSearch();
                    })();
                    """
                ),
                auto_focus=True,
                placeholder="Search documentation ...",
                class_name="py-2 pl-7 md:pr-[310px] w-full placeholder:text-sm text-sm rounded-lg outline-none focus:outline-none",
            ),
            class_name="w-full relative focus:outline-none",
        ),
        class_name="w-full flex flex-col absolute top-0 left-0 p-3 z-[999]",
    )


def search_content():
    return rx.scroll_area(
        rx.box(
            rx.cond(
                query.value.to(str).strip() != "",
                rx.cond(
                    docs.value.to(List[DocDict]).length() > 0,
                    rx.foreach(
                        docs.value.to(List[DocDict]),
                        lambda doc: rx.box(
                            *[
                                rx.el.p(
                                    rx.fragment(
                                        rx.el.strong("Title: "),
                                        doc["item"]["title"],
                                    ),
                                ),
                                rx.el.p(
                                    rx.fragment(
                                        rx.el.strong("Author: "),
                                        doc["item"]["author"]["firstName"]
                                        + " "
                                        + doc["item"]["author"]["lastName"],
                                    ),
                                ),
                                rx.el.p(
                                    rx.fragment(
                                        rx.el.strong("Score: "),
                                        f"{doc['score']:.6f}",
                                    ),
                                ),
                            ],
                            font_size="14px",
                        ),
                    ),
                    no_results_found(),
                ),
            ),
            class_name="flex flex-col gap-y-2 px-2",
        ),
        class_name="w-full h-full pt-11 [&_.rt-ScrollAreaScrollbar]:mr-[0.1875rem] [&_.rt-ScrollAreaScrollbar]:mt-[3rem]",
    )


def fuse_search_front_end_only() -> rx.Component:
    """Create the main search component for Reflex Web"""
    return rx.dialog.root(
        rx.dialog.trigger(search_trigger(), id="search-trigger"),
        rx.dialog.content(
            search_input(),
            search_content(),
            class_name="w-full max-w-[650px] mx-auto outline-none p-3 h-[57vh]",
        ),
    )


def center_fuse_front_end_search():
    return rx.box(
        docs,
        query,
        rx.box(
            fuse_search_front_end_only(),
            class_name="flex w-full items-center justify-center max-w-72",
        ),
        class_name="flex w-full items-center justify-center",
    )



import reflex as rx
from typing import Literal
from reflex.experimental import ClientStateVar
from src.docs.library.base_ui.components.base.input_group import input_with_addons
from src.docs.library.base_ui.components.base.button import button
from src.docs.library.base_ui.components.base.badge import badge
import src.hooks as hooks

selected = ClientStateVar.create("selected", "vm")


def checkout_form():
    return rx.el.div(
        rx.el.div(
            rx.form(
                rx.el.div(
                    # Payment Method Section
                    rx.el.fieldset(
                        rx.el.legend(
                            "Payment Method",
                            data_slot="field-legend",
                            data_variant="legend",
                            class_name="mb-3 font-medium data-[variant=legend]:text-base data-[variant=label]:text-sm",
                        ),
                        rx.el.p(
                            "All transactions are secure and encrypted",
                            data_slot="field-description",
                            class_name="text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5 [&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4",
                        ),
                        rx.el.div(
                            # Name on Card
                            rx.el.div(
                                rx.el.label(
                                    "Name on Card",
                                    html_for="checkout-7j9-card-name-43j",
                                    data_slot="field-label",
                                    class_name="items-center text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10",
                                ),
                                rx.el.input(
                                    id="checkout-7j9-card-name-43j",
                                    placeholder="John Doe",
                                    required=True,
                                    data_slot="input",
                                    class_name="file:text-foreground placeholder:text-muted-foreground selection:bg-primary selection:text-primary-foreground dark:bg-input/30 border-input h-9 w-full min-w-0 rounded-md border bg-transparent px-3 py-1 text-base shadow-xs transition-[color,box-shadow] outline-none file:inline-flex file:h-7 file:border-0 file:bg-transparent file:text-sm file:font-medium disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",
                                ),
                                role="group",
                                data_slot="field",
                                data_orientation="vertical",
                                class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-col [&>*]:w-full [&>.sr-only]:w-auto",
                            ),
                            # Card Number and CVV Grid
                            rx.el.div(
                                rx.el.div(
                                    rx.el.label(
                                        "Card Number",
                                        html_for="checkout-7j9-card-number-uw1",
                                        data_slot="field-label",
                                        class_name="items-center text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10",
                                    ),
                                    rx.el.input(
                                        id="checkout-7j9-card-number-uw1",
                                        placeholder="1234 5678 9012 3456",
                                        required=True,
                                        data_slot="input",
                                        class_name="file:text-foreground placeholder:text-muted-foreground selection:bg-primary selection:text-primary-foreground dark:bg-input/30 border-input h-9 w-full min-w-0 rounded-md border bg-transparent px-3 py-1 text-base shadow-xs transition-[color,box-shadow] outline-none file:inline-flex file:h-7 file:border-0 file:bg-transparent file:text-sm file:font-medium disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",
                                    ),
                                    rx.el.p(
                                        "Enter your 16-digit number.",
                                        data_slot="field-description",
                                        class_name="text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5 [&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4",
                                    ),
                                    role="group",
                                    data_slot="field",
                                    data_orientation="vertical",
                                    class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-col [&>*]:w-full [&>.sr-only]:w-auto col-span-2",
                                ),
                                rx.el.div(
                                    rx.el.label(
                                        "CVV",
                                        html_for="checkout-7j9-cvv",
                                        data_slot="field-label",
                                        class_name="items-center text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10",
                                    ),
                                    rx.el.input(
                                        id="checkout-7j9-cvv",
                                        placeholder="123",
                                        required=True,
                                        data_slot="input",
                                        class_name="file:text-foreground placeholder:text-muted-foreground selection:bg-primary selection:text-primary-foreground dark:bg-input/30 border-input h-9 w-full min-w-0 rounded-md border bg-transparent px-3 py-1 text-base shadow-xs transition-[color,box-shadow] outline-none file:inline-flex file:h-7 file:border-0 file:bg-transparent file:text-sm file:font-medium disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",
                                    ),
                                    role="group",
                                    data_slot="field",
                                    data_orientation="vertical",
                                    class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-col [&>*]:w-full [&>.sr-only]:w-auto col-span-1",
                                ),
                                class_name="grid grid-cols-3 gap-4",
                            ),
                            # Month and Year Grid
                            rx.el.div(
                                rx.el.div(
                                    rx.el.label(
                                        "Month",
                                        html_for="checkout-7j9-exp-month-ts6",
                                        data_slot="field-label",
                                        class_name="items-center text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10",
                                    ),
                                    rx.el.select(
                                        rx.el.option(
                                            "MM", value="", disabled=True, selected=True
                                        ),
                                        rx.el.option("01", value="01"),
                                        rx.el.option("02", value="02"),
                                        rx.el.option("03", value="03"),
                                        rx.el.option("04", value="04"),
                                        rx.el.option("05", value="05"),
                                        rx.el.option("06", value="06"),
                                        rx.el.option("07", value="07"),
                                        rx.el.option("08", value="08"),
                                        rx.el.option("09", value="09"),
                                        rx.el.option("10", value="10"),
                                        rx.el.option("11", value="11"),
                                        rx.el.option("12", value="12"),
                                        id="checkout-7j9-exp-month-ts6",
                                        class_name="border-input data-[placeholder]:text-muted-foreground dark:bg-input/30 flex w-full items-center justify-between gap-2 rounded-md border bg-transparent px-3 py-2 text-sm shadow-xs transition-[color,box-shadow] outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50 h-9",
                                    ),
                                    role="group",
                                    data_slot="field",
                                    data_orientation="vertical",
                                    class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-col [&>*]:w-full [&>.sr-only]:w-auto",
                                ),
                                rx.el.div(
                                    rx.el.label(
                                        "Year",
                                        html_for="checkout-7j9-exp-year-f59",
                                        data_slot="field-label",
                                        class_name="items-center text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10",
                                    ),
                                    rx.el.select(
                                        rx.el.option(
                                            "YYYY",
                                            value="",
                                            disabled=True,
                                            selected=True,
                                        ),
                                        rx.el.option("2024", value="2024"),
                                        rx.el.option("2025", value="2025"),
                                        rx.el.option("2026", value="2026"),
                                        rx.el.option("2027", value="2027"),
                                        rx.el.option("2028", value="2028"),
                                        rx.el.option("2029", value="2029"),
                                        id="checkout-7j9-exp-year-f59",
                                        class_name="border-input data-[placeholder]:text-muted-foreground dark:bg-input/30 flex w-full items-center justify-between gap-2 rounded-md border bg-transparent px-3 py-2 text-sm shadow-xs transition-[color,box-shadow] outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50 h-9",
                                    ),
                                    role="group",
                                    data_slot="field",
                                    data_orientation="vertical",
                                    class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-col [&>*]:w-full [&>.sr-only]:w-auto",
                                ),
                                class_name="grid grid-cols-2 gap-4",
                            ),
                            data_slot="field-group",
                            class_name="group/field-group @container/field-group flex w-full flex-col gap-7 data-[slot=checkbox-group]:gap-3 [&>[data-slot=field-group]]:gap-4",
                        ),
                        data_slot="field-set",
                        class_name="flex flex-col gap-6 has-[>[data-slot=checkbox-group]]:gap-3 has-[>[data-slot=radio-group]]:gap-3",
                    ),
                    # Separator
                    rx.el.div(
                        rx.el.div(
                            data_orientation="horizontal",
                            role="none",
                            data_slot="separator",
                            class_name="bg-border shrink-0 data-[orientation=horizontal]:h-px data-[orientation=horizontal]:w-full data-[orientation=vertical]:h-full data-[orientation=vertical]:w-px absolute inset-0 top-1/2",
                        ),
                        data_slot="field-separator",
                        data_content="false",
                        class_name="relative -my-2 h-5 text-sm group-data-[variant=outline]/field-group:-mb-2",
                    ),
                    # Billing Address Section
                    rx.el.fieldset(
                        rx.el.legend(
                            "Billing Address",
                            data_slot="field-legend",
                            data_variant="legend",
                            class_name="mb-3 font-medium data-[variant=legend]:text-base data-[variant=label]:text-sm",
                        ),
                        rx.el.p(
                            "The billing address associated with your payment method",
                            data_slot="field-description",
                            class_name="text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5 [&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4",
                        ),
                        rx.el.div(
                            rx.el.div(
                                rx.el.input(
                                    type="checkbox",
                                    id="checkout-7j9-same-as-shipping-wgm",
                                    checked=True,
                                    class_name="peer border-input dark:bg-input/30 size-4 shrink-0 rounded-[4px] border shadow-xs transition-shadow outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50",
                                ),
                                rx.el.label(
                                    "Same as shipping address",
                                    html_for="checkout-7j9-same-as-shipping-wgm",
                                    data_slot="field-label",
                                    class_name="items-center text-sm select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10 font-normal",
                                ),
                                role="group",
                                data_slot="field",
                                data_orientation="horizontal",
                                class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-row items-center [&>[data-slot=field-label]]:flex-auto has-[>[data-slot=field-content]]:items-start has-[>[data-slot=field-content]]:[&>[role=checkbox],[role=radio]]:mt-px",
                            ),
                            data_slot="field-group",
                            class_name="group/field-group @container/field-group flex w-full flex-col gap-7 data-[slot=checkbox-group]:gap-3 [&>[data-slot=field-group]]:gap-4",
                        ),
                        data_slot="field-set",
                        class_name="flex flex-col gap-6 has-[>[data-slot=checkbox-group]]:gap-3 has-[>[data-slot=radio-group]]:gap-3",
                    ),
                    # Separator
                    rx.el.div(
                        rx.el.div(
                            data_orientation="horizontal",
                            role="none",
                            data_slot="separator",
                            class_name="bg-border shrink-0 data-[orientation=horizontal]:h-px data-[orientation=horizontal]:w-full data-[orientation=vertical]:h-full data-[orientation=vertical]:w-px absolute inset-0 top-1/2",
                        ),
                        data_slot="field-separator",
                        data_content="false",
                        class_name="relative -my-2 h-5 text-sm group-data-[variant=outline]/field-group:-mb-2",
                    ),
                    # Comments Section
                    rx.el.fieldset(
                        rx.el.div(
                            rx.el.div(
                                rx.el.label(
                                    "Comments",
                                    html_for="checkout-7j9-optional-comments",
                                    data_slot="field-label",
                                    class_name="items-center text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10",
                                ),
                                rx.el.textarea(
                                    id="checkout-7j9-optional-comments",
                                    placeholder="Add any additional comments",
                                    data_slot="textarea",
                                    class_name="border-input placeholder:text-muted-foreground focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive dark:bg-input/30 flex field-sizing-content min-h-16 w-full rounded-md border bg-transparent px-3 py-2 text-base shadow-xs transition-[color,box-shadow] outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50 md:text-sm",
                                ),
                                role="group",
                                data_slot="field",
                                data_orientation="vertical",
                                class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-col [&>*]:w-full [&>.sr-only]:w-auto",
                            ),
                            data_slot="field-group",
                            class_name="group/field-group @container/field-group flex w-full flex-col gap-7 data-[slot=checkbox-group]:gap-3 [&>[data-slot=field-group]]:gap-4",
                        ),
                        data_slot="field-set",
                        class_name="flex flex-col gap-6 has-[>[data-slot=checkbox-group]]:gap-3 has-[>[data-slot=radio-group]]:gap-3",
                    ),
                    # Submit and Cancel Buttons
                    rx.el.div(
                        button("Submit"),
                        button("Cancel", variant="outline"),
                        class_name="flex flex-row items-center gap-x-4 [&>[data-slot=field-label]]:flex-auto has-[>[data-slot=field-content]]:items-start has-[>[data-slot=field-content]]:[&>[role=checkbox],[role=radio]]:mt-px",
                    ),
                    data_slot="field-group",
                    class_name="group/field-group @container/field-group flex w-full flex-col gap-7 data-[slot=checkbox-group]:gap-3 [&>[data-slot=field-group]]:gap-4",
                ),
                class_name="w-full rounded-lg border border-[var(--input)] p-6",
            ),
            class_name="flex flex-col gap-6 *:[div]:w-full *:[div]:max-w-full",
        ),
    )


def input_group():
    return rx.el.div(
        rx.el.textarea(
            data_slot="input-group-control",
            class_name="border-input placeholder:text-muted-foreground focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive flex field-sizing-content min-h-16 w-full px-3 text-base transition-[color,box-shadow] outline-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm flex-1 resize-none rounded-none border-0 bg-transparent py-3 shadow-none focus-visible:ring-0 dark:bg-transparent",
            placeholder="Ask, Search or Chat...",
        ),
        rx.el.div(
            rx.el.button(
                rx.html(
                    """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="tabler-icon tabler-icon-plus "><path d="M12 5l0 14"></path><path d="M5 12l14 0"></path></svg>"""
                ),
                data_slot="button",
                class_name="justify-center whitespace-nowrap font-medium transition-all disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 shrink-0 [&_svg]:shrink-0 outline-none focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive border bg-background hover:bg-accent hover:text-accent-foreground dark:bg-input/30 dark:border-input dark:hover:bg-input/50 text-sm shadow-none flex gap-2 items-center size-6 p-0 has-[>svg]:p-0 rounded-full",
                type="button",
                data_size="icon-xs",
                aria_label="Add",
            ),
            rx.el.button(
                "Auto",
                data_slot="dropdown-menu-trigger",
                class_name="justify-center whitespace-nowrap font-medium transition-all disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 shrink-0 [&_svg]:shrink-0 outline-none focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive hover:bg-accent hover:text-accent-foreground dark:hover:bg-accent/50 py-2 text-sm shadow-none flex items-center h-6 gap-1 px-2 rounded-[calc(var(--radius)-5px)] [&>svg:not([class*='size-'])]:size-3.5 has-[>svg]:px-2",
                type="button",
                data_size="xs",
                id="radix-«rhm»",
                aria_haspopup="menu",
                aria_expanded="false",
                data_state="closed",
            ),
            rx.el.span(
                "52% used",
                class_name="text-muted-foreground flex items-center gap-2 text-sm [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 ml-auto",
            ),
            rx.el.div(
                data_orientation="vertical",
                role="none",
                data_slot="separator",
                class_name="bg-border shrink-0 data-[orientation=horizontal]:h-px data-[orientation=horizontal]:w-full data-[orientation=vertical]:h-full data-[orientation=vertical]:w-px !h-4",
            ),
            rx.el.button(
                rx.html(
                    """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-arrow-up"><path d="m5 12 7-7 7 7"></path><path d="M12 19V5"></path></svg>"""
                ),
                rx.el.span("Send", class_name="sr-only"),
                data_slot="button",
                class_name="justify-center whitespace-nowrap font-medium transition-all disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 shrink-0 [&_svg]:shrink-0 outline-none focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive bg-primary text-primary-foreground hover:bg-primary/90 text-sm shadow-none flex gap-2 items-center size-6 p-0 has-[>svg]:p-0 rounded-full",
                type="button",
                data_size="icon-xs",
            ),
            role="group",
            data_slot="input-group-addon",
            data_align="block-end",
            class_name="text-muted-foreground flex h-auto cursor-text items-center gap-2 py-1.5 text-sm font-medium select-none [&>svg:not([class*='size-'])]:size-4 [&>kbd]:rounded-[calc(var(--radius)-5px)] group-data-[disabled=true]/input-group:opacity-50 order-last w-full justify-start px-3 pb-3 [.border-t]:pt-3 group-has-[>input]/input-group:pb-2.5",
        ),
        data_slot="input-group",
        role="group",
        class_name="group/input-group border-input dark:bg-input/30 relative flex w-full items-center rounded-md border shadow-xs transition-[color,box-shadow] outline-none h-9 min-w-0 has-[>textarea]:h-auto has-[>[data-align=inline-start]]:[&>input]:pl-2 has-[>[data-align=inline-end]]:[&>input]:pr-2 has-[>[data-align=block-start]]:h-auto has-[>[data-align=block-start]]:flex-col has-[>[data-align=block-start]]:[&>input]:pb-3 has-[>[data-align=block-end]]:h-auto has-[>[data-align=block-end]]:flex-col has-[>[data-align=block-end]]:[&>input]:pt-3 has-[[data-slot=input-group-control]:focus-visible]:border-ring has-[[data-slot=input-group-control]:focus-visible]:ring-ring/50 has-[[data-slot=input-group-control]:focus-visible]:ring-[3px] has-[[data-slot][aria-invalid=true]]:ring-destructive/20 has-[[data-slot][aria-invalid=true]]:border-destructive dark:has-[[data-slot][aria-invalid=true]]:ring-destructive/40",
    )


class CheckboxState(rx.State):
    social_media: bool = True
    search_engine: bool = False
    referral: bool = False
    other: bool = False

    def toggle_social_media(self):
        self.social_media = not self.social_media

    def toggle_search_engine(self):
        self.search_engine = not self.search_engine

    def toggle_referral(self):
        self.referral = not self.referral

    def toggle_other(self):
        self.other = not self.other


def checkbox_button(id_val: str, value: str, label: str, is_checked: bool, on_click):
    return rx.el.label(
        rx.el.div(
            rx.el.button(
                rx.cond(is_checked, rx.icon("check", size=12), rx.fragment()),
                type="button",
                role="checkbox",
                aria_checked=rx.cond(is_checked, "true", "false"),
                data_state=rx.cond(is_checked, "checked", "unchecked"),
                value=value,
                data_slot="checkbox",
                id=id_val,
                on_click=on_click,
                class_name="peer dark:bg-input/30 data-[state=checked]:bg-primary data-[state=checked]:text-primary-foreground dark:data-[state=checked]:bg-primary data-[state=checked]:border-input focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive size-4 shrink-0 border shadow-xs outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50 -ml-6 -translate-x-1 rounded-full transition-all duration-100 ease-linear data-[state=checked]:ml-0 data-[state=checked]:translate-x-0 flex items-center justify-center",
            ),
            rx.el.input(
                type="checkbox",
                value=value,
                checked=is_checked,
                aria_hidden="true",
                tab_index=-1,
                style={
                    "position": "absolute",
                    "pointer-events": "none",
                    "opacity": "0",
                    "margin": "0px",
                    "transform": "translateX(-100%)",
                    "width": "16px",
                    "height": "16px",
                },
            ),
            rx.el.div(
                label,
                data_slot="field-label",
                class_name="flex w-fit items-center gap-2 text-sm leading-snug font-medium group-data-[disabled=true]/field:opacity-50",
            ),
            role="group",
            data_slot="field",
            data_orientation="horizontal",
            class_name="group/field flex w-full data-[invalid=true]:text-destructive flex-row items-center [&>[data-slot=field-label]]:flex-auto has-[>[data-slot=field-content]]:items-start has-[>[data-slot=field-content]]:[&>[role=checkbox],[role=radio]]:mt-px gap-1.5 overflow-hidden !px-3 !py-1.5 transition-all duration-100 ease-linear group-has-data-[state=checked]/field-label:!px-2",
        ),
        html_for=id_val,
        data_slot="field-label",
        data_state=rx.cond(is_checked, "checked", "unchecked"),
        class_name="items-center text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 border-input has-data-[state=checked]:border-input dark:has-data-[state=checked]:bg-primary/10 !w-fit",
    )


def checkbox_form():
    return rx.el.div(
        rx.form(
            rx.el.div(
                rx.el.fieldset(
                    rx.el.legend(
                        "How did you hear about us?",
                        data_slot="field-legend",
                        data_variant="legend",
                        class_name="mb-3 font-medium data-[variant=legend]:text-base data-[variant=label]:text-sm",
                    ),
                    rx.el.p(
                        "Select the option that best describes how you heard about us.",
                        data_slot="field-description",
                        class_name="text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5 [&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4 line-clamp-1",
                    ),
                    rx.el.div(
                        checkbox_button(
                            "social-media",
                            "social-media",
                            "Social Media",
                            CheckboxState.social_media,
                            CheckboxState.toggle_social_media,
                        ),
                        checkbox_button(
                            "search-engine",
                            "search-engine",
                            "Search Engine",
                            CheckboxState.search_engine,
                            CheckboxState.toggle_search_engine,
                        ),
                        checkbox_button(
                            "referral",
                            "referral",
                            "Referral",
                            CheckboxState.referral,
                            CheckboxState.toggle_referral,
                        ),
                        checkbox_button(
                            "other",
                            "other",
                            "Other",
                            CheckboxState.other,
                            CheckboxState.toggle_other,
                        ),
                        data_slot="field-group",
                        class_name="group/field-group @container/field-group w-full data-[slot=checkbox-group]:gap-3 [&>[data-slot=field-group]]:gap-4 flex flex-row flex-wrap gap-2 [--radius:9999rem]",
                    ),
                    data_slot="field-set",
                    class_name="flex flex-col has-[>[data-slot=checkbox-group]]:gap-3 has-[>[data-slot=radio-group]]:gap-3 gap-4",
                ),
                data_slot="field-group",
                class_name="group/field-group @container/field-group flex w-full flex-col gap-7 data-[slot=checkbox-group]:gap-3 [&>[data-slot=field-group]]:gap-4",
            ),
        ),
        data_slot="card-content",
    )


def input_type_one():
    return input_with_addons(
        prefix=rx.icon("search", size=14),
        placeholder="Search...",
        suffix="12 results",
        class_name="pl-2",
    )


def input_type_two():
    return input_with_addons(
        placeholder="@SapphireUI",
        suffix=button(
            rx.icon("check", size=10),
            size="icon-sm",
            class_name="!size-4 !rounded-full !flex !items-center !justify-center",
        ),
        class_name="pr-2",
    )


def input_type_three():
    return input_with_addons(
        prefix="https://",
        placeholder="example.com",
        suffix=rx.tooltip(
            rx.icon("info", size=14),
            content="This is content in a tooltip.",
            class_name="text-sm py-1.5 font-medium",
        ),
        class_name="pr-2",
    )


def button_group(
    *children,
    orientation: Literal["horizontal", "vertical"] = "horizontal",
    class_name: str = "",
    **props,
):
    """
    Button group component for grouping related buttons together.
    Uses CSS variables from your shadcn theme.

    Args:
        *children: Button elements to group
        orientation: Layout direction (horizontal or vertical)
        class_name: Additional classes
        **props: Additional props for the group element
    """
    base_classes = (
        "flex w-fit items-stretch [&>*]:focus-visible:z-10 [&>*]:focus-visible:relative "
        "[&>[data-slot=select-trigger]:not([class*='w-'])]:w-fit [&>input]:flex-1 "
        "has-[select[aria-hidden=true]:last-child]:[&>[data-slot=select-trigger]:last-of-type]:rounded-r-md "
        "has-[>[data-slot=button-group]]:gap-2"
    )

    orientation_classes = {
        "horizontal": (
            "[&>*:not(:first-child)]:rounded-l-none [&>*:not(:first-child)]:border-l-0 "
            "[&>*:not(:last-child)]:rounded-r-none"
        ),
        "vertical": (
            "flex-col [&>*:not(:first-child)]:rounded-t-none [&>*:not(:first-child)]:border-t-0 "
            "[&>*:not(:last-child)]:rounded-b-none"
        ),
    }

    return rx.box(
        *children,
        role="group",
        data_slot="button-group",
        data_orientation=orientation,
        class_name=f"{base_classes} {orientation_classes[orientation]} {class_name}".strip(),
        **props,
    )


def button_group_text(*children, class_name: str = "", **props):
    """
    Text/label element for button groups.
    Used for displaying static text alongside buttons.

    Args:
        *children: Text or icon content
        class_name: Additional classes
        **props: Additional props
    """
    base_classes = (
        "bg-[var(--muted)] flex items-center gap-2 rounded-md border px-4 text-sm font-medium "
        "shadow-xs [&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4"
    )

    return rx.box(*children, class_name=f"{base_classes} {class_name}".strip(), **props)


def button_group_separator(
    orientation: Literal["horizontal", "vertical"] = "vertical",
    class_name: str = "",
    **props,
):
    """
    Separator line between button group elements.

    Args:
        orientation: Separator direction
        class_name: Additional classes
        **props: Additional props
    """
    base_classes = (
        "bg-[var(--input)] relative !m-0 self-stretch "
        "data-[orientation=vertical]:h-auto"
    )

    # Use rx.divider for the separator
    return rx.divider(
        data_slot="button-group-separator",
        orientation=orientation,
        class_name=f"{base_classes} {class_name}".strip(),
        **props,
    )


def button_group_demo():
    """Basic button group example"""
    return rx.box(
        button_group(
            rx.el.button(
                "First",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "bg-[var(--primary)] text-[var(--primary-foreground)] "
                    "hover:bg-[var(--primary)]/90 h-9 px-4 py-2 text-sm font-medium "
                    "transition-all outline-none border border-transparent"
                ),
            ),
            rx.el.button(
                "Second",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "bg-[var(--primary)] text-[var(--primary-foreground)] "
                    "hover:bg-[var(--primary)]/90 h-9 px-4 py-2 text-sm font-medium "
                    "transition-all outline-none border border-transparent"
                ),
            ),
            rx.el.button(
                "Third",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "bg-[var(--primary)] text-[var(--primary-foreground)] "
                    "hover:bg-[var(--primary)]/90 h-9 px-4 py-2 text-sm font-medium "
                    "transition-all outline-none border border-transparent"
                ),
            ),
        ),
    )


def button_group_outline():
    """Button group with outline variant"""
    return rx.box(
        button_group(
            rx.el.button(
                "Copy",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            rx.el.button(
                "Cut",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            rx.el.button(
                "Paste",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
        ),
    )


def button_group_with_separator():
    """Button group with separators"""
    return rx.box(
        button_group(
            rx.el.button(
                "Bold",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            button_group_separator(),
            rx.el.button(
                "Italic",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            button_group_separator(),
            rx.el.button(
                "Underline",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
        ),
    )


def button_group_with_text():
    """Button group with text label"""
    return rx.box(
        button_group(
            rx.el.button(
                "Name",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            rx.el.button(
                "Date",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            rx.el.button(
                "Size",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
        ),
    )


def button_group_vertical():
    """Vertical button group"""
    return rx.box(
        button_group(
            rx.el.button(
                "Top",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            rx.el.button(
                "Middle",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            rx.el.button(
                "Bottom",
                class_name=(
                    "inline-flex items-center justify-center gap-2 rounded-md "
                    "border bg-[var(--background)] shadow-xs hover:bg-[var(--accent)] "
                    "hover:text-[var(--accent-foreground)] "
                    "dark:bg-[var(--input)]/30 dark:border-[var(--input)] "
                    "dark:hover:bg-[var(--input)]/50 "
                    "h-9 px-4 py-2 text-sm font-medium transition-all outline-none"
                ),
            ),
            orientation="vertical",
        ),
    )


def component():
    return rx.el.div(
        rx.el.div(
            # Icon / Avatar group
            rx.el.div(
                rx.el.div(
                    # Avatar 1
                    rx.el.span(
                        rx.el.img(
                            data_slot="avatar-image",
                            class_name="aspect-square size-full",
                            src="https://avatars.githubusercontent.com/u/224980531?s=400&u=c5d05d850c7a0a918342cb95ad434c9ec6302c86&v=4",
                        ),
                        data_slot="avatar",
                        class_name="relative flex size-8 shrink-0 overflow-hidden rounded-full",
                    ),
                    # Avatar 2
                    rx.el.span(
                        rx.el.img(
                            data_slot="avatar-image",
                            class_name="aspect-square size-full",
                            src="https://avatars.githubusercontent.com/u/123644743?s=400&u=4544a6bb80651d28bc3f2f5464ff551c9e4aee68&v=4",
                        ),
                        data_slot="avatar",
                        class_name="relative flex size-8 shrink-0 overflow-hidden rounded-full",
                    ),
                    # Avatar 3
                    rx.el.span(
                        rx.el.img(
                            data_slot="avatar-image",
                            class_name="aspect-square size-full",
                            src="https://avatars.githubusercontent.com/u/104714959?s=200&v=4",
                        ),
                        data_slot="avatar",
                        class_name="relative flex size-8 shrink-0 overflow-hidden rounded-full",
                    ),
                    class_name=(
                        "*:data-[slot=avatar]:ring-background flex -space-x-2 "
                        "*:data-[slot=avatar]:size-12 *:data-[slot=avatar]:ring-2 "
                        "*:data-[slot=avatar]:grayscale"
                    ),
                ),
                data_slot="empty-icon",
                data_variant="default",
                class_name=(
                    "flex shrink-0 items-center justify-center mb-2 "
                    "[&_svg]:pointer-events-none [&_svg]:shrink-0 bg-transparent"
                ),
            ),
            # Title
            rx.el.div(
                "No Team Members",
                data_slot="empty-title",
                class_name="text-lg font-medium tracking-tight",
            ),
            # Description
            rx.el.div(
                "Invite your team to collaborate on this project.",
                data_slot="empty-description",
                class_name=(
                    "text-muted-foreground [&>a:hover]:text-primary text-sm/relaxed "
                    "[&>a]:underline [&>a]:underline-offset-4"
                ),
            ),
            data_slot="empty-header",
            class_name="flex max-w-sm flex-col items-center gap-2 text-center",
        ),
        # === Content Section ===
        rx.el.div(
            rx.el.button(
                "Invite Members",
                data_slot="button",
                class_name=(
                    "inline-flex items-center justify-center whitespace-nowrap text-sm font-medium "
                    "transition-all disabled:pointer-events-none disabled:opacity-50 "
                    "[&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 "
                    "shrink-0 [&_svg]:shrink-0 outline-none focus-visible:border-ring "
                    "focus-visible:ring-ring/50 focus-visible:ring-[3px] "
                    "aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 "
                    "aria-invalid:border-destructive bg-primary text-primary-foreground "
                    "hover:bg-primary/90 h-8 rounded-md gap-1.5 px-3 has-[>svg]:px-2.5"
                ),
            ),
            data_slot="empty-content",
            class_name=(
                "flex w-full max-w-sm min-w-0 flex-col items-center gap-4 "
                "text-sm text-balance"
            ),
        ),
        # === Root Wrapper ===
        data_slot="empty",
        class_name=(
            "flex min-w-0 flex-col items-center justify-center gap-6 rounded-lg border-dashed "
            "p-6 text-center text-balance md:p-12 flex-none border border-input"
        ),
    )


def component_two():
    return rx.el.fieldset(
        rx.el.legend(
            "Compute Environment",
            data_slot="field-legend",
            data_variant="legend",
            class_name="mb-3 font-medium data-[variant=legend]:text-base data-[variant=label]:text-sm",
        ),
        rx.el.p(
            "Select the compute environment for your cluster.",
            data_slot="field-description",
            class_name="text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5 [&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4",
        ),
        rx.el.div(
            rx.el.label(
                rx.el.div(
                    rx.el.div(
                        rx.el.div(
                            "Kubernetes",
                            data_slot="field-label",
                            class_name="flex w-fit items-center gap-2 text-sm leading-snug font-medium group-data-[disabled=true]/field:opacity-50",
                        ),
                        rx.el.p(
                            "Run GPU workloads on a K8s configured cluster. This is the default.",
                            data_slot="field-description",
                            class_name="text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5 [&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4",
                        ),
                        data_slot="field-content",
                        class_name="group/field-content flex flex-1 flex-col gap-1.5 leading-snug",
                    ),
                    rx.el.input(
                        type="radio",
                        role="radio",
                        checked=selected.value == "kubernetes",
                        data_state=rx.cond(
                            selected.value == "kubernetes", "checked", "unchecked"
                        ),
                        value="kubernetes",
                        data_slot="radio-group-item",
                        class_name="accent-primary border-input text-primary focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive dark:bg-input/30 aspect-square size-4 shrink-0 rounded-full border shadow-xs transition-[color,box-shadow] outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50",
                        id="kubernetes-r2h",
                        aria_label="Kubernetes",
                        tab_index=0,
                        data_radix_collection_item=True,
                        on_click=selected.set_value("kubernetes"),
                    ),
                    role="group",
                    data_slot="field",
                    data_orientation="horizontal",
                    class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-row items-center [&>[data-slot=field-label]]:flex-auto has-[>[data-slot=field-content]]:items-start has-[>[data-slot=field-content]]:[&>[role=checkbox],[role=radio]]:mt-px",
                ),
                data_slot="field-label",
                class_name="items-center border border-input text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10",
                html_for="kubernetes-r2h",
            ),
            rx.el.label(
                rx.el.div(
                    rx.el.div(
                        rx.el.div(
                            "Virtual Machine",
                            data_slot="field-label",
                            class_name="flex w-fit items-center gap-2 text-sm leading-snug font-medium group-data-[disabled=true]/field:opacity-50",
                        ),
                        rx.el.p(
                            "Access a VM configured cluster to run workloads. (Coming soon)",
                            data_slot="field-description",
                            class_name="text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5 [&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4",
                        ),
                        data_slot="field-content",
                        class_name="group/field-content flex flex-1 flex-col gap-1.5 leading-snug",
                    ),
                    rx.el.input(
                        type="radio",
                        role="radio",
                        checked=selected.value == "vm",
                        data_state=rx.cond(
                            selected.value == "vm", "checked", "unchecked"
                        ),
                        value="vm",
                        data_slot="radio-group-item",
                        class_name="accent-primary border-input text-primary focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive dark:bg-input/30 aspect-square size-4 shrink-0 rounded-full border shadow-xs transition-[color,box-shadow] outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50",
                        id="vm-z4k",
                        aria_label="Virtual Machine",
                        tab_index=-1,
                        data_radix_collection_item=True,
                        on_click=selected.set_value("vm"),
                    ),
                    role="group",
                    data_slot="field",
                    data_orientation="horizontal",
                    class_name="group/field flex w-full gap-3 data-[invalid=true]:text-destructive flex-row items-center [&>[data-slot=field-label]]:flex-auto has-[>[data-slot=field-content]]:items-start has-[>[data-slot=field-content]]:[&>[role=checkbox],[role=radio]]:mt-px",
                ),
                data_slot="field-label",
                class_name="items-center border border-input text-sm font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50 group/field-label peer/field-label flex w-fit gap-2 leading-snug group-data-[disabled=true]/field:opacity-50 has-[>[data-slot=field]]:w-full has-[>[data-slot=field]]:flex-col has-[>[data-slot=field]]:rounded-md has-[>[data-slot=field]]:border [&>*]:data-[slot=field]:p-4 has-data-[state=checked]:bg-primary/5 has-data-[state=checked]:border-primary dark:has-data-[state=checked]:bg-primary/10",
                html_for="vm-z4k",
            ),
            role="radiogroup",
            aria_required=False,
            dir="ltr",
            data_slot="radio-group",
            class_name="grid gap-3",
            tab_index=0,
            style={"outline": "none"},
        ),
        data_slot="field-set",
        class_name="flex flex-col gap-4 has-[>[data-slot=checkbox-group]]:gap-3 has-[>[data-slot=radio-group]]:gap-3 p-2",
    )


def loading_empty_state():
    """Empty state component with loading spinner."""
    return rx.el.div(
        rx.el.div(
            rx.html(
                """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-loader-circle size-4 animate-spin" role="status" aria-label="Loading"><path d="M21 12a9 9 0 1 1-6.219-8.56"></path></svg>"""
            ),
            data_slot="empty-icon",
            data_variant="icon",
            class_name="mb-2 [&_svg]:pointer-events-none [&_svg]:shrink-0 bg-muted text-foreground flex size-10 shrink-0 items-center justify-center rounded-lg [&_svg:not([class*='size-'])]:size-6",
        ),
        rx.el.div(
            "Processing your request",
            data_slot="empty-title",
            class_name="text-lg font-medium tracking-tight",
        ),
        rx.el.div(
            "Please wait while we process your request. Do not refresh the page.",
            data_slot="empty-description",
            class_name="text-muted-foreground [&>a:hover]:text-primary text-sm/relaxed [&>a]:underline [&>a]:underline-offset-4",
        ),
        button("Cancel", variant="outline"),
        data_slot="empty-header",
        class_name="flex max-w-sm flex-col items-center gap-2 text-center border border-input rounded-lg p-4",
    )


def loading_badges():
    """Three loading badges with different variants."""
    return rx.el.div(
        rx.el.div(
            badge(
                rx.html(
                    """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-loader-circle size-4 animate-spin" role="status" aria-label="Loading"><path d="M21 12a9 9 0 1 1-6.219-8.56"></path></svg>"""
                ),
                "Syncing",
            ),
            badge(
                rx.html(
                    """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-loader-circle size-4 animate-spin" role="status" aria-label="Loading"><path d="M21 12a9 9 0 1 1-6.219-8.56"></path></svg>"""
                ),
                "Updating",
                variant="secondary",
            ),
            badge(
                rx.html(
                    """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-loader-circle size-4 animate-spin" role="status" aria-label="Loading"><path d="M21 12a9 9 0 1 1-6.219-8.56"></path></svg>"""
                ),
                "Loading",
                variant="outline",
            ),
            class_name="flex items-center gap-2 [--radius:1.2rem]",
        ),
        class_name="flex flex-row",
    )


def pagination_button_groups():
    """Pagination component with button groups for page numbers and navigation."""
    return rx.el.div(
        rx.el.div(
            rx.el.div(
                button("1", variant="outline", size="sm"),
                button("2", variant="outline", size="sm"),
                button("3", variant="outline", size="sm"),
                role="group",
                data_slot="button-group",
                class_name="flex w-fit items-stretch [&>*]:focus-visible:z-10 [&>*]:focus-visible:relative [&>[data-slot=select-trigger]:not([class*='w-'])]:w-fit [&>input]:flex-1 has-[select[aria-hidden=true]:last-child]:[&>[data-slot=select-trigger]:last-of-type]:rounded-r-md has-[>[data-slot=button-group]]:gap-2 [&>*:not(:first-child)]:rounded-l-none [&>*:not(:first-child)]:border-l-0 [&>*:not(:last-child)]:rounded-r-none",
            ),
            role="group",
            data_slot="button-group",
            class_name="flex w-fit items-stretch [&>*]:focus-visible:z-10 [&>*]:focus-visible:relative [&>[data-slot=select-trigger]:not([class*='w-'])]:w-fit [&>input]:flex-1 has-[select[aria-hidden=true]:last-child]:[&>[data-slot=select-trigger]:last-of-type]:rounded-r-md has-[>[data-slot=button-group]]:gap-2 [&>*:not(:first-child)]:rounded-l-none [&>*:not(:first-child)]:border-l-0 [&>*:not(:last-child)]:rounded-r-none",
        ),
        rx.el.div(
            button(
                rx.html(
                    """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-arrow-left"><path d="m12 19-7-7 7-7"></path><path d="M19 12H5"></path></svg>"""
                ),
                aria_label="Previous",
                variant="outline",
                size="sm",
                class_name="size-8",
            ),
            button(
                rx.html(
                    """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-arrow-right"><path d="M5 12h14"></path><path d="m12 5 7 7-7 7"></path></svg>"""
                ),
                aria_label="Next",
                variant="outline",
                size="sm",
                class_name="size-8",
            ),
            role="group",
            data_slot="button-group",
            class_name="flex w-fit items-stretch [&>*]:focus-visible:z-10 [&>*]:focus-visible:relative [&>[data-slot=select-trigger]:not([class*='w-'])]:w-fit [&>input]:flex-1 has-[select[aria-hidden=true]:last-child]:[&>[data-slot=select-trigger]:last-of-type]:rounded-r-md has-[>[data-slot=button-group]]:gap-2 [&>*:not(:first-child)]:rounded-l-none [&>*:not(:first-child)]:border-l-0 [&>*:not(:last-child)]:rounded-r-none",
        ),
        rx.el.div(
            button(
                rx.html(
                    """<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-bot"><path d="M12 8V4H8"></path><rect width="16" height="12" x="4" y="8" rx="2"></rect><path d="M2 14h2"></path><path d="M20 14h2"></path><path d="M15 13v2"></path><path d="M9 13v2"></path></svg>"""
                ),
                " Copilot",
                variant="outline",
                size="sm",
                # class_name="size-8"
            ),
            role="group",
            data_slot="button-group",
            class_name="flex w-fit items-stretch [&>*]:focus-visible:z-10 [&>*]:focus-visible:relative [&>[data-slot=select-trigger]:not([class*='w-'])]:w-fit [&>input]:flex-1 has-[select[aria-hidden=true]:last-child]:[&>[data-slot=select-trigger]:last-of-type]:rounded-r-md has-[>[data-slot=button-group]]:gap-2 [&>*:not(:first-child)]:rounded-l-none [&>*:not(:first-child)]:border-l-0 [&>*:not(:last-child)]:rounded-r-none",
        ),
        class_name="flex flex-row items-center justify-between gap-4",
    )


tooltip = {
    "is_animation_active": False,
    "separator": "",
    "cursor": False,
    "item_style": {
        "color": "currentColor",
        "display": "flex",
        "paddingBottom": "0px",
        "justifyContent": "space-between",
        "textTransform": "capitalize",
    },
    "label_style": {
        "color": rx.color("slate", 10),
        "fontWeight": "500",
    },
    "content_style": {
        "background": rx.color_mode_cond("oklch(0.97 0.00 0)", "oklch(0.14 0.00 286)"),
        "borderColor": rx.color("slate", 5),
        "borderRadius": "5px",
        "fontFamily": "IBM Plex Mono,ui-monospace,monospace",
        "fontSize": "0.875rem",
        "lineHeight": "1.25rem",
        "fontWeight": "500",
        "letterSpacing": "-0.01rem",
        "minWidth": "8rem",
        "width": "175px",
        "padding": "0.375rem 0.625rem ",
        "position": "relative",
    },
}


def info(title: str, size: str, subtitle: str, align: str):
    return rx.vstack(
        rx.heading(title, size=size, weight="bold"),
        rx.text(subtitle, size="1", color=rx.color("slate", 11), weight="medium"),
        spacing="1",
        align=align,
    )


def get_tooltip():
    """Standard tooltip for all charts."""
    return rx.recharts.graphing_tooltip(**tooltip)


def get_cartesian_grid():
    """Standard cartesian grid for charts."""
    return rx.recharts.cartesian_grid(
        horizontal=True, vertical=False, class_name="opacity-25"
    )


def get_x_axis(data_key: str):
    """Standard X axis configuration."""
    return rx.recharts.x_axis(
        data_key=data_key,
        axis_line=False,
        tick_size=10,
        tick_line=False,
        custom_attrs={"fontSize": "12px"},
        interval="preserveStartEnd",
    )


def barchart_v9():
    data = [
        {"month": "Jan", "desktop": 186, "mobile": 80, "tablet": 50},
        {"month": "Feb", "desktop": 305, "mobile": 200, "tablet": 120},
        {"month": "Mar", "desktop": 237, "mobile": 120, "tablet": 70},
        # {"month": "Apr", "desktop": 73, "mobile": 190, "tablet": 30},
        # {"month": "May", "desktop": 209, "mobile": 130, "tablet": 80},
    ]

    return rx.box(
        rx.hstack(
            rx.foreach(
                [
                    ["Desktop", "var(--chart-1)"],
                    ["Mobile", "var(--chart-2)"],
                    ["Tablet", "var(--chart-3)"],
                ],
                lambda key: rx.hstack(
                    rx.box(class_name="w-3 h-3 rounded-sm", bg=key[1]),
                    rx.text(
                        key[0],
                        class_name="text-sm font-semibold",
                        color=rx.color("slate", 11),
                    ),
                    align="center",
                    spacing="2",
                ),
            ),
            class_name="py-4 px-4 flex w-full flex justify-center gap-8",
        ),
        rx.recharts.bar_chart(
            get_tooltip(),
            rx.recharts.bar(data_key="desktop", fill="var(--chart-1)", radius=4),
            rx.recharts.bar(data_key="mobile", fill="var(--chart-2)", radius=4),
            rx.recharts.bar(data_key="tablet", fill="var(--chart-3)", radius=4),
            get_x_axis("month"),
            data=data,
            width="100%",
            height=250,
        ),
        class_name="w-full flex flex-col gap-y-4 [&_.recharts-tooltip-item-separator]:w-full",
    )


def linechart_v8():
    data = [
        {"month": "Jan", "desktop": 186, "mobile": 80},
        {"month": "Feb", "desktop": 305, "mobile": 200},
        {"month": "Mar", "desktop": 237, "mobile": 120},
        {"month": "Apr", "desktop": 73, "mobile": 190},
        {"month": "May", "desktop": 209, "mobile": 130},
        {"month": "Jun", "desktop": 214, "mobile": 140},
    ]
    return rx.box(
        rx.recharts.line_chart(
            get_tooltip(),
            rx.recharts.line(
                data_key="desktop",
                stroke="var(--chart-1)",
                type_="linear",
                dot=False,
                stroke_width=2,
            ),
            rx.recharts.line(
                data_key="mobile",
                stroke="var(--chart-3)",
                type_="linear",
                dot=False,
                stroke_width=2,
            ),
            get_x_axis("month"),
            data=data,
            width="100%",
            height=250,
        ),
        rx.hstack(
            rx.foreach(
                [["Desktop", "var(--chart-1)"], ["Mobile", "var(--chart-3)"]],
                lambda key: rx.hstack(
                    rx.box(class_name="w-3 h-3 rounded-sm", bg=key[1]),
                    rx.text(
                        key[0],
                        class_name="text-sm font-semibold",
                        color=rx.color("slate", 11),
                    ),
                    align="center",
                    spacing="2",
                ),
            ),
            class_name="py-4 px-4 flex w-full flex justify-center gap-8",
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )


def areachart_v5():
    import datetime
    import random

    start_date = datetime.date(2024, 4, 1)
    data = [
        {
            "date": (start_date + datetime.timedelta(days=i)).strftime("%b %d"),
            "desktop": random.randint(80, 500),
            "mobile": random.randint(100, 550),
        }
        for i in range(30)
    ]

    def gradient(id_: str, color: str):
        return rx.el.svg.linear_gradient(
            rx.el.svg.stop(stop_color=f"var(--{color})", offset="5%", stop_opacity=0.8),
            rx.el.svg.stop(
                stop_color=f"var(--{color})", offset="95%", stop_opacity=0.1
            ),
            x1=0,
            x2=0,
            y1=0,
            y2=1,
            id=id_,
        )

    def area(data_key: str, color: str):
        return rx.recharts.area(
            data_key=data_key,
            fill=f"url(#{data_key})",
            stack_id="a",
            stroke=f"var(--{color})",
            animation_easing="linear",
        )

    return rx.box(
        rx.recharts.area_chart(
            rx.el.svg.defs(
                gradient("desktop", "chart-1"),
                gradient("mobile", "chart-2"),
            ),
            get_tooltip(),
            get_cartesian_grid(),
            area("mobile", "chart-2"),
            area("desktop", "chart-1"),
            rx.recharts.x_axis(
                data_key="date",
                axis_line=False,
                min_tick_gap=32,
                tick_size=10,
                tick_line=False,
                custom_attrs={"fontSize": "12px"},
                interval="preserveStartEnd",
            ),
            data=data,
            width="100%",
            height=280,
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )


def examples_page():
    # Define column groups for better organization
    column_one = [
        checkout_form(),
    ]

    column_two = [
        component(),
        loading_badges(),
        input_type_one(),
        barchart_v9(),
        input_type_two(),
        input_type_three(),
    ]

    column_three = [
        linechart_v8(),
        component_two(),
        loading_empty_state(),
    ]

    column_four = [
        input_group(),
        checkbox_form(),
        areachart_v5(),
        pagination_button_groups(),
    ]

    return rx.el.div(
        rx.el.div(
            # Column 1
            rx.el.div(
                *column_one,
                class_name="w-full flex flex-col gap-6",
            ),
            # Column 2
            rx.el.div(
                *column_two,
                class_name="w-full flex flex-col gap-6",
            ),
            # Column 3
            rx.el.div(
                *column_three,
                class_name="w-full flex flex-col gap-6",
            ),
            # Column 4
            rx.el.div(
                *column_four,
                class_name="w-full flex flex-col gap-6",
            ),
            class_name=" ".join(
                [
                    "mx-auto",
                    "grid gap-6",
                    "grid-cols-1",  # Mobile: 1 column
                    "sm:grid-cols-2",  # Small: 2 columns
                    "md:grid-cols-2",  # Medium: 2 columns (2x2 layout)
                    "lg:grid-cols-3",  # Large: 3 columns
                    "xl:grid-cols-4",  # XL: 4 columns
                    "sm:gap-6",  # Responsive gaps
                    "lg:gap-8",
                    "xl:gap-6",
                    "2xl:gap-8",
                    "py-1",
                ]
            ),
        ),
        class_name="w-full overflow-hidden p-4 sm:p-6 lg:p-8 "  # Responsive padding
        + rx.color_mode_cond(
            f"theme-{hooks.current_theme.value}",
            f"theme-{hooks.current_theme.value}-dark",
        ).to(str),
    )



import reflex as rx

from src.docs.library.charts.util import (
    info,
    get_tooltip,
)


def radar_v4():
    stats = [
        {"category": "Farming", "score": 8, "average": 8},
        {"category": "Fighting", "score": 7, "average": 9},
        {"category": "Aggressiveness", "score": 6, "average": 8},
        {"category": "Map Awareness", "score": 5, "average": 9},
        {"category": "Objective Control", "score": 9, "average": 8},
        {"category": "Positioning", "score": 7, "average": 9},
    ]

    return rx.vstack(
        info(
            "Radar Chart - Lines Only",
            "3",
            "Player performance across key gameplay categories",
            "center",
        ),
        rx.recharts.radar_chart(
            get_tooltip(),
            rx.recharts.polar_grid(
                class_name=rx.color_mode_cond(
                    "text-sm stroke-gray-300",
                    "text-sm stroke-gray-700",
                ),
            ),
            rx.recharts.polar_angle_axis(
                data_key="category",
                class_name=rx.color_mode_cond(
                    "text-sm stroke-gray-300",
                    "text-sm stroke-gray-700",
                ),
            ),
            rx.recharts.radar(
                data_key="average",
                stroke="teal",
                fill="none",
                custom_attrs={"strokeWidth": 2},
            ),
            rx.recharts.radar(
                data_key="score",
                fill="none",
                stroke="var(--chart-1)",
                custom_attrs={"strokeWidth": 2},
            ),
            data=stats,
            width="100%",
            height=250,
            margin={"left": 20, "right": 20},
        ),
        info(
            "Trending up by 5.2% this month",
            "2",
            "Performance trends in key gameplay categories",
            "center",
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 items-center [&_.recharts-tooltip-item-separator]:w-full",
    )



import reflex as rx


def site_title():
    return rx.el.div(
        rx.el.p(
            "Sapphire",
            font_weight="700",
            font_size="1.25rem",
            letter_spacing="-0.04em",
        ),
        rx.el.p(
            "UI",
            font_size="0.50rem",
            position="relative",
            font_weight="600",
        ),
        class_name="flex flex-row items-baseline gap-x-[1px] cursor-pointer",
    )



import reflex as rx
from src.docs.library.charts.util import (
    get_tooltip,
    get_x_axis,
)


def barchart_v10():
    sport = [
        {"date": "Jan 23", "Running": 167, "Cycling": 145},
        {"date": "Feb 23", "Running": 125, "Cycling": 110},
        {"date": "Mar 23", "Running": 156, "Cycling": 149},
        {"date": "Apr 23", "Running": 165, "Cycling": 112},
        {"date": "May 23", "Running": 153, "Cycling": 138},
        {"date": "Jun 23", "Running": 124, "Cycling": 145},
        {"date": "Jul 23", "Running": 164, "Cycling": 134},
    ]

    activities = ["Running", "Cycling"]
    chart_colors = ["var(--chart-1)", "var(--chart-2)"]

    def create_alternating_chart(active_key: str):
        return rx.recharts.bar_chart(
            get_tooltip(),
            *[
                rx.recharts.bar(
                    is_animation_active=False,
                    radius=4,
                    data_key=key,
                    fill=color,
                    custom_attrs={
                        "opacity": rx.cond(
                            key == active_key,
                            "0.25",
                            "1",
                        )
                    },
                )
                for key, color in zip(activities, chart_colors)
            ],
            get_x_axis("date"),
            data=sport,
            width="100%",
            height=250,
            bar_category_gap="20%",
        )

    return rx.box(
        rx.tabs.root(
            rx.tabs.list(
                *[
                    rx.tabs.trigger(
                        rx.text(activity, class_name="text-sm font-semibold"),
                        value=str(i + 1),
                    )
                    for i, activity in enumerate(activities)
                ]
            ),
            *[
                rx.tabs.content(
                    create_alternating_chart(active),
                    value=str(i + 1),
                    margin_top="-5px",
                )
                for i, active in enumerate(activities)
            ],
            default_value="1",
            width="100%",
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )



import reflex as rx
from ...base_ui.components.base.kbd import kbd_group, kbd


def kbd_demo():
    """
    Example matching the shadcn KbdDemo component.
    Shows keyboard shortcuts with modifier keys.
    """
    return rx.box(
        # Mac modifier keys
        kbd_group(
            kbd("⌘"),
            kbd("⇧"),
            kbd("⌥"),
            kbd("⌃"),
        ),
        # Keyboard shortcut combination
        kbd_group(
            kbd("Ctrl"),
            rx.el.span("+"),
            kbd("B"),
        ),
        class_name="flex flex-col items-center gap-4 p-8",
    )


# Additional examples


def kbd_shortcuts():
    """Common keyboard shortcuts"""
    return rx.box(
        rx.box(
            rx.text("Save:", class_name="text-sm font-medium mr-2"),
            kbd_group(
                kbd("Ctrl"),
                rx.el.span("+"),
                kbd("S"),
            ),
            class_name="flex items-center",
        ),
        rx.box(
            rx.text("Copy:", class_name="text-sm font-medium mr-2"),
            kbd_group(
                kbd("Ctrl"),
                rx.el.span("+"),
                kbd("C"),
            ),
            class_name="flex items-center",
        ),
        rx.box(
            rx.text("Paste:", class_name="text-sm font-medium mr-2"),
            kbd_group(
                kbd("Ctrl"),
                rx.el.span("+"),
                kbd("V"),
            ),
            class_name="flex items-center",
        ),
        rx.box(
            rx.text("Undo:", class_name="text-sm font-medium mr-2"),
            kbd_group(
                kbd("Ctrl"),
                rx.el.span("+"),
                kbd("Z"),
            ),
            class_name="flex items-center",
        ),
        class_name="flex flex-col gap-3 p-8",
    )


def kbd_special_keys():
    """Special key examples"""
    return rx.box(
        kbd("Enter"),
        kbd("Esc"),
        kbd("Tab"),
        kbd("Space"),
        kbd("←"),
        kbd("→"),
        kbd("↑"),
        kbd("↓"),
        kbd("Delete"),
        kbd("Backspace"),
        class_name="flex flex-wrap gap-2 p-8",
    )


def kbd_complex_shortcuts():
    """Complex multi-key shortcuts"""
    return rx.box(
        # Three modifier keys
        rx.box(
            rx.text("Screenshot:", class_name="text-sm font-medium mr-2"),
            kbd_group(
                kbd("Ctrl"),
                rx.el.span("+"),
                kbd("Shift"),
                rx.el.span("+"),
                kbd("S"),
            ),
            class_name="flex items-center mb-3",
        ),
        # Mac command
        rx.box(
            rx.text("Quit:", class_name="text-sm font-medium mr-2"),
            kbd_group(
                kbd("⌘"),
                rx.el.span("+"),
                kbd("Q"),
            ),
            class_name="flex items-center mb-3",
        ),
        # Function key
        rx.box(
            rx.text("Full Screen:", class_name="text-sm font-medium mr-2"),
            kbd("F11"),
            class_name="flex items-center",
        ),
        class_name="p-8",
    )


def kbd_with_icons():
    """Kbd with icons"""
    return rx.box(
        kbd_group(
            kbd(
                rx.icon(tag="command", size=12),
            ),
            rx.el.span("+"),
            kbd("K"),
        ),
        kbd_group(
            kbd(
                rx.icon(tag="arrow-left", size=12),
            ),
            kbd(
                rx.icon(tag="arrow-right", size=12),
            ),
        ),
        class_name="flex flex-col items-center gap-4 p-8",
    )



import reflex as rx


def quill_stylesheet():
    return rx.el.link(
        href="https://cdn.jsdelivr.net/npm/quill@2.0.3/dist/quill.snow.css",
        rel="stylesheet",
    )


def quill_custom_font():
    return rx.el.link(
        href="https://fonts.googleapis.com/css?family=Aref+Ruqaa|Mirza|Roboto",
        rel="stylesheet",
    )


def quill_lib():
    return rx.script(src="https://cdn.jsdelivr.net/npm/quill@2.0.3/dist/quill.js")


def quill_init():
    return rx.script(
        """
        setTimeout(function() {
            const quill = new Quill('#quill-editor', {
                theme: 'snow',
                placeholder: 'When Mr. Bilbo Baggins of Bag End announced that he would shortly be celebrating his eleventy-first birthday with a party of special magnificence, there was much talk and excitement in Hobbiton.',
            });
        }, 1000);
    """
    )



import reflex as rx
from src.docs.library.base_ui.components.base.breadcrumb import (
    breadcrumb,
    breadcrumb_ellipsis,
    breadcrumb_item,
    breadcrumb_list,
    breadcrumb_link,
    breadcrumb_separator,
    breadcrumb_page,
)


def breadcrumb_demo():
    return rx.el.div(
        breadcrumb(
            breadcrumb_list(
                breadcrumb_item(
                    breadcrumb_link("Home", href="#"),
                ),
                breadcrumb_separator(),
                breadcrumb_item(
                    rx.menu.root(
                        rx.menu.trigger(
                            rx.box(
                                breadcrumb_ellipsis(class_name="size-4"),
                                rx.el.span("Toggle menu", class_name="sr-only"),
                                class_name="flex items-center gap-1",
                            ),
                        ),
                        rx.menu.content(
                            rx.menu.item("Documentation"),
                            rx.menu.item("Themes"),
                            rx.menu.item("GitHub"),
                            class_name="min-w-[8rem]",
                        ),
                    ),
                ),
                breadcrumb_separator(),
                breadcrumb_item(
                    breadcrumb_link("Components", href="#"),
                ),
                breadcrumb_separator(),
                breadcrumb_item(
                    breadcrumb_page("Breadcrumb"),
                ),
            ),
        ),
        class_name="p-8",
    )


def breadcrumb_simple():
    return rx.box(
        breadcrumb(
            breadcrumb_list(
                breadcrumb_item(
                    breadcrumb_link("Home", href="#"),
                ),
                breadcrumb_separator(),
                breadcrumb_item(
                    breadcrumb_link("Products", href="#"),
                ),
                breadcrumb_separator(),
                breadcrumb_item(
                    breadcrumb_link("Electronics", href="#"),
                ),
                breadcrumb_separator(),
                breadcrumb_item(
                    breadcrumb_page("Laptop"),
                ),
            ),
        ),
        class_name="p-8",
    )


def breadcrumb_with_icons():
    return rx.el.div(
        breadcrumb(
            breadcrumb_list(
                breadcrumb_item(
                    breadcrumb_link(
                        rx.icon(tag="home", size=14),
                        "Home",
                        href="#",
                        class_name="flex flex-row gap-x-1 items-center",
                    ),
                ),
                breadcrumb_separator(),
                breadcrumb_item(
                    breadcrumb_link(
                        rx.icon(tag="folder", size=14),
                        "Documents",
                        href="#",
                        class_name="flex flex-row gap-x-1 items-center",
                    ),
                ),
                breadcrumb_separator(),
                breadcrumb_item(
                    breadcrumb_page(
                        rx.icon(tag="file-text", size=14),
                        "README.md",
                        class_name="flex flex-row gap-x-1 items-center",
                    ),
                ),
            ),
        ),
        class_name="p-8",
    )


def breadcrumb_custom_separator():
    return rx.el.div(
        breadcrumb(
            breadcrumb_list(
                breadcrumb_item(
                    breadcrumb_link("Home", href="#"),
                ),
                breadcrumb_separator(
                    rx.text("/", class_name="text-[var(--muted-foreground)]")
                ),
                breadcrumb_item(
                    breadcrumb_link("Blog", href="#"),
                ),
                breadcrumb_separator(
                    rx.text("/", class_name="text-[var(--muted-foreground)]")
                ),
                breadcrumb_item(
                    breadcrumb_page("Article"),
                ),
            ),
        ),
        class_name="p-8",
    )



from enum import Enum
from typing import List, Dict
from pathlib import Path
from dataclasses import dataclass

import reflex as rx


# --- Markdown Command Constants ---
class DocParserCommands(str, Enum):
    DEMO_AND_CODE_SINGLE_FILE = "demo_and_code_single_file"
    SHOW_CODE_WITH_LANGUAGE = "show_code_with_language"
    DEMO_AND_SINGLE_FUNCTION = "demo_and_single_function"
    FULL_SOURCE_PAGE_OF_COMPONENT = "full_source_page_of_component"
    CLI_AND_MANUAL_INSTALLATION = "cli_and_manual_installation"


# --- Generated Doc Type ---
@dataclass
class DocDataStruct:
    """The data structure for the generated doc page"""

    url: str
    component: List[rx.Component]
    table_of_content: List[Dict]


# --- Docs Path Constants ---
DOCS_BASE_DIR = Path("docs")
DOCS_LIBRARY_ROOT = "src/docs/library"



import reflex as rx
from ...base_ui.components.base.link import link


def link_example():
    """A basic link example."""
    return link("This is a link", href="#")


def link_sizes():
    """Link examples with different sizes."""
    return rx.box(
        link("X-Small Link", href="#", size="xs"),
        link("Small Link", href="#", size="sm"),
        link("Medium Link", href="#", size="md"),
        link("Large Link", href="#", size="lg"),
        link("X-Large Link", href="#", size="xl"),
        class_name="flex flex-col items-start gap-4",
    )


def link_variants():
    """Link examples with different variants."""
    return rx.box(
        link("Primary Link", href="#", variant="primary"),
        link("Secondary Link", href="#", variant="secondary"),
        class_name="flex flex-col items-start gap-4",
    )


def link_with_icon():
    """Link example with an icon."""
    return link("Link with icon", href="#", show_icon=True)



import reflex as rx

import src.meta as meta
import src.routes as routes

from src.docs.generator import generate_docs_library
from src.views.landing.landing import site_landing_page
from src.templates.docpage import docpage
from src.templates.toc import table_of_content


landing = site_landing_page()


def export(app: rx.App):
    # landing page
    app.add_page(
        landing,
        route="/",
        title="The UI Library for Reflex Developers - SapphireUI",
        meta=meta.SITE_META_TAGS,
    )

    # redirect if wrong url
    app.add_page(
        rx.fragment(),
        route="/docs",
        on_load=lambda: rx.redirect(routes.GET_STARTED_URLS[0]["url"]),
    )

    # Add all the documentation pages.
    for doc in generate_docs_library():
        main_content = rx.el.div(*doc.component, class_name="w-full")
        toc_content = table_of_content(doc.url, doc.table_of_content)

        title_s = doc.url.split("/")[-1].replace("-", " ").title()
        title = f"{title_s} – SapphireUI"

        app.add_page(
            docpage(main_content, toc_content),
            route=f"/{doc.url}",
            title=title,
            meta=meta.SITE_META_TAGS,
        )



import reflex as rx
from ...base_ui.components.base.textarea import textarea


def textarea_demo():
    return rx.el.div(
        rx.el.p("Textarea", class_name="text-sm font-medium mb-2"),
        textarea(
            placeholder="Enter your message here...",
        ),
        class_name="w-full max-w-md p-8",
    )


def textarea_disabled():
    return rx.el.div(
        rx.el.p("Disabled Textarea", class_name="text-sm font-medium mb-2"),
        textarea(
            placeholder="This is disabled",
            disabled=True,
        ),
        class_name="w-full max-w-md p-8",
    )


def textarea_custom():
    return rx.el.div(
        rx.el.p("Custom Height", class_name="text-sm font-medium mb-2"),
        textarea(
            placeholder="Taller textarea",
            class_name="min-h-32",
        ),
        class_name="w-full max-w-md p-8",
    )



import reflex as rx
from src.docs.library.base_ui.components.base.input import input


def input_demo():
    return rx.el.div(
        rx.text("Text Input", class_name="text-sm font-medium mb-2"),
        input(
            type="text",
            placeholder="Enter your name",
        ),
        class_name="w-full max-w-md p-8",
    )


def input_email():
    return rx.el.div(
        rx.el.p("Email Input", class_name="text-sm font-medium mb-2"),
        input(
            type="email",
            placeholder="name@example.com",
        ),
        class_name="w-full max-w-md p-8",
    )


def input_password():
    return rx.el.div(
        rx.el.p("Password Input", class_name="text-sm font-medium mb-2"),
        input(
            type="password",
            placeholder="Enter your password",
        ),
        class_name="w-full max-w-md p-8",
    )


def input_disabled():
    return rx.el.div(
        rx.el.p("Disabled Input", class_name="text-sm font-medium mb-2"),
        input(
            type="text",
            placeholder="Disabled input",
            disabled=True,
        ),
        class_name="w-full max-w-md p-8",
    )


def input_file():
    return rx.el.div(
        rx.el.p("File Input", class_name="text-sm font-medium mb-2"),
        input(
            type="file",
        ),
        class_name="w-full max-w-md p-8",
    )


def input_custom_width():
    return rx.el.div(
        rx.el.p("Custom Width", class_name="text-sm font-medium mb-2"),
        input(
            type="text",
            placeholder="Max width 300px",
            class_name="max-w-[300px]",
        ),
        class_name="w-full max-w-md p-8",
    )



import reflex as rx
from ...base_ui.components.base.button import button
from ...base_ui.components.base.menu import menu


def dropdown_menu_demo():
    return rx.el.div(
        menu.root(
            menu.trigger(
                button("Click Me!", variant="outline"),
            ),
            menu.portal(
                menu.positioner(
                    menu.popup(
                        menu.group(
                            menu.group_label("My Account"),
                            menu.item(
                                "Profile",
                                rx.text(
                                    "⇧⌘P",
                                    class_name="ml-auto text-xs tracking-widest text-muted-foreground",
                                ),
                            ),
                            menu.item(
                                "Billing",
                                rx.text(
                                    "⌘B",
                                    class_name="ml-auto text-xs tracking-widest text-muted-foreground",
                                ),
                            ),
                            menu.item(
                                "Settings",
                                rx.text(
                                    "⌘S",
                                    class_name="ml-auto text-xs tracking-widest text-muted-foreground",
                                ),
                            ),
                            menu.item(
                                "Keyboard shortcuts",
                                rx.text(
                                    "⌘K",
                                    class_name="ml-auto text-xs tracking-widest text-muted-foreground",
                                ),
                            ),
                        ),
                        menu.separator(),
                        menu.item("Team"),
                        menu.submenu_root(
                            menu.submenu_trigger(
                                "Invite users",
                                rx.icon("chevron-right", class_name="ml-auto size-4"),
                            ),
                            menu.portal(
                                menu.positioner(
                                    menu.popup(
                                        menu.item("Email"),
                                        menu.item("Message"),
                                        menu.separator(),
                                        menu.item("More..."),
                                        class_name="w-44",
                                    ),
                                ),
                            ),
                        ),
                        menu.item(
                            "New Team",
                            rx.text(
                                "⌘+T",
                                class_name="ml-auto text-xs tracking-widest text-muted-foreground",
                            ),
                        ),
                        menu.separator(),
                        menu.item("GitHub"),
                        menu.item("Support"),
                        menu.item("API", disabled=True),
                        menu.separator(),
                        menu.item(
                            "Log out",
                            rx.text(
                                "⇧⌘Q",
                                class_name="ml-auto text-xs tracking-widest text-muted-foreground",
                            ),
                        ),
                        class_name="w-56",
                    ),
                ),
            ),
        ),
        class_name="p-8",
    )



import reflex as rx

from src.docs.library.charts.util import (
    info,
    get_tooltip,
)


def piechart_v6():
    data = [
        {"browser": "chrome", "visitors": 275},
        {"browser": "safari", "visitors": 200},
        {"browser": "firefox", "visitors": 187},
        {"browser": "edge", "visitors": 173},
        {"browser": "other", "visitors": 90},
    ]

    return rx.box(
        info("Pie Chart - Active", "3", "January - June 2024", "center"),
        rx.recharts.pie_chart(
            get_tooltip(),
            rx.recharts.pie(
                rx.foreach(
                    range(6),
                    lambda color, index: rx.recharts.cell(
                        fill=f"var(--chart-{index + 1})",
                    ),
                ),
                data=data,
                data_key="visitors",
                name_key="browser",
                stroke="0",
                inner_radius=60,
                custom_attrs={
                    "strokeWidth": 5,
                    "activeIndex": 1,
                    "activeShape": {"outerRadius": 120},
                },
            ),
            width="100%",
            height=250,
        ),
        info(
            "Trending up by 5.2% this month",
            "2",
            "Showing total visitors for the last 6 months",
            "center",
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 items-center [&_.recharts-tooltip-item-separator]:w-full",
    )
